OC.L10N.register(
    "spreed",
    {
    "a conversation" : "розмова",
    "(Duration %s)" : "(Тривалість %s)",
    "You attended a call with {user1}" : "Ви були на дзвінку з {user1}",
    "_%n guest_::_%n guests_" : ["%n гість","%n гостя","%n гостей","%n гостей"],
    "You attended a call with {user1} and {user2}" : "Ви були на дзвінку з {user1} і {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Ви були на дзвінку з {user1}, {user2} і {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Ви були на дзвінку з {user1}, {user2}, {user3} і {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Ви були на дзвінку з {user1}, {user2}, {user3}, {user4} і {user5}",
    "_%n other_::_%n others_" : ["%nінший","%nінших","%n інших","%n інших"],
    "{actor} invited you to {call}" : "{actor} запросив вас на {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Вас запросили на <strong>розмову</strong> або <strong>вам подзвонили</strong>",
    "Other activities" : "Інші події",
    "Talk" : "Розмови",
    "Guest" : "Гість",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Ласкаво просимо до Nextcloud Talk!\nУ цій розмові ви дізнаєтесь про нові функції, доступні в Nextcloud Talk.",
    "## New in Talk %s" : "Нове в застосунку Talk версії %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "— Microsoft Edge і Safari тепер можна використовувати для участі в аудіо- та відеодзвінках",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "— Розмови «один на один» тепер постійні й більше не можуть бути випадково перетворені на групові. Крім того, коли один із учасників залишає розмову, розмова більше не видаляється автоматично. Лише якщо обидва учасники виходять, розмова видаляється з сервера",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Тепер ви можете повідомити всіх учасників, написавши \"@all\" у чаті",
    "- With the \"arrow-up\" key you can repost your last message" : "- За допомогою клавіші зі стрілкою вгору ви можете повторно розмістити своє останнє повідомлення",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk тепер може мати команди, надішліть \"/help\" як повідомлення чату, щоб дізнатися, чи ваш адміністратор налаштував деякі",
    "- With projects you can create quick links between conversations, files and other items" : "- За допомогою проектів ви можете створювати швидкі посилання між розмовами, файлами та іншими елементами",
    "- You can now mention guests in the chat" : "- Тепер ви можете згадувати гостей у чаті",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "Дозволити гостям приєднуватися через посилання",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Тепер ви можете безпосередньо відповідати на повідомлення, надаючи іншим користувачам більше інформації про ваше повідомлення",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Пошук розмов і учасників тепер також фільтруватиме ваші наявні розмови, що полегшить пошук попередніх розмов",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Після того як буде увімкнено застосунок \"Кола\", ви зможете додавати власні групи користувачів до розмов",
    "- Check out the new grid and call view" : "- Перегляньте нову сітку та вигляд викликів",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Тепер ви можете завантажувати та перетягувати файли прямо зі свого пристрою в чат",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Спільні файли тепер відкриваються безпосередньо в поданні чату у застосунку перегляду",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Тепер ви можете шукати чати та повідомлення в уніфікованому пошуку на верхній панелі",
    "- Spice up your messages with emojis from the emoji picker" : "- Доповніть ваші повідомлення - додайте емоційки до тексту",
    "- You can now change your camera and microphone while being in a call" : "- Тепер ви можете змінити камеру та мікрофон під час розмови",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Надайте своїм розмовам певний контекст за допомогою опису та відкрийте його, щоб користувачі, які ввійшли в систему, могли знайти його та приєднатися",
    "- See a read status and send failed messages again" : "- Перегляньте статус прочитання та знову надішліть повідомлення, які не вдалося надіслати",
    "- Raise your hand in a call with the R key" : "- Підніміть руку під час виклику за допомогою клавіші R",
    "- Join the same conversation and call from multiple devices" : "- Приєднуйтесь до однієї розмови та телефонуйте з кількох пристроїв",
    "- Send voice messages, share your location or contact details" : "- Надсилайте голосові повідомлення, діліться власним місцем розташування або контактними даними",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Додайте групи до розмови, і нові учасники групи будуть автоматично додані як учасники",
    "- A preview of your audio and video is shown before joining a call" : "- Попередній перегляд аудіо та відео відображається перед приєднанням до виклику",
    "- You can now blur your background in the newly designed call view" : "- Тепер ви можете розмити фон у новому режимі перегляду викликів",
    "- Moderators can now assign general and individual permissions to participants" : "— Модератори тепер можуть призначати загальні та індивідуальні дозволи учасникам",
    "- You can now react to chat messages" : "- Тепер ви можете відповідати на повідомлення чату",
    "- In the sidebar you can now find an overview of the latest shared items" : "- На бічній панелі тепер ви можете знайти огляд останніх спільних елементів",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Використовуйте опитування, щоб зібрати думки інших або домовитися про побачення",
    "- Configure an expiration time for chat messages" : "- Налаштуйте термін дії повідомлень чату",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Починайте дзвінки без сповіщення інших під час великих розмов. Ви можете надсилати індивідуальні сповіщення про виклик, щойно він розпочався.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Надсилайте повідомлення в чаті без сповіщення одержувачів, якщо це не є терміновим",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Емодзі тепер можна автозаповнювати, ввівши \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Пов'язуйте різні об'єкти з використанням асистенту розумного вибору, для цього просто введіть \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Модератори тепер можуть створювати окремі кімнати (потрібен високопродуктивний бекенд)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Дзвінки тепер можна записувати (потрібен Високопродуктивний бекенд)",
    "- Conversations can now have an avatar or emoji as icon" : "- Тепер у розмовах можна поставити аватарку або емодзі як іконку",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- На додаток до розмитого фону у відеодзвінках тепер доступні віртуальні фони",
    "- Reactions are now available during calls" : "- Реакції тепер доступні під час дзвінка",
    "- Typing indicators show which users are currently typing a message" : "- Індикатори набору тексту показують, які користувачі в даний момент набирають повідомлення",
    "- Groups can now be mentioned in chats" : "- Групи тепер можна згадувати в чатах",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Записи дзвінків автоматично транскрибуються, якщо зареєстровано застосунок постачальника послуг з транскрибування",
    "- Chat messages can be translated if a translation provider app is registered" : "- Повідомлення чату можна перекладати, якщо зареєстровано застосунок перекладу",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** розмітку тепер можна використовувати в повідомленнях _чату_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Для реалізації ботів тепер доступні веб-хуки. Дивіться документацію для отримання додаткової інформації https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Встановіть нагадування в повідомленні чату, щоб пізніше знову отримати сповіщення ",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Використовуйте розмову **Нотатки для себе**, щоб робити нотатки та обмінюватися інформацією між своїми пристроями",
    "- Captions allow to send a message with a file at the same time" : "- Підписи дозволяють одночасно надсилати повідомлення з файлом",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Відео спікера тепер видно під час спільного доступу до екрана, а реакція на виклик анімована",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Відтепер повідомлення можуть редагувати автори та модератори, що увійшли в систему, протягом 6 годин",
    "- Unsent message drafts are now saved in your browser" : "- Чернетки невідправлених повідомлень тепер зберігаються у вашому браузері",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Текстовий чат тепер можна використовувати у федеративному режимі з іншими серверами Talk",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Модератори тепер можуть банити акаунти та гостей, щоб запобігти їхньому повторному приєднанню до розмови",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Майбутні дзвінки з прив'язаних подій календаря та заміни поза офісом тепер відображаються в розмовах",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Дзвінки тепер можна здійснювати у федеративний спосіб з іншими Talk-серверами (потрібен високопродуктивний бекенд)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Представляємо десктопний клієнт Nextcloud Talk для Windows, macOS та Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Підсумовуйте записи дзвінків і непрочитані повідомлення в чатах за допомогою Nextcloud Assistant",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Покращення зустрічей завдяки розпізнаванню гостей, запрошених за їхньою електронною адресою, імпорту списків учасників, проектів опитувань та завантаженню списків учасників дзвінків.",
    "- Archive conversations to stay focused" : "- Архівуйте розмови, щоб залишатися зосередженими",
    "- Schedule a meeting into your calendar from within a conversation" : "- Заплануйте зустріч у своєму календарі з розмови",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Пошук повідомлень поточної розмови безпосередньо в правій бічній панелі",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Переглядайте більше розмов з першого погляду з новим компактним списком (увімкніть у налаштуваннях розмови)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Розмови про зустрічі тепер синхронізуються з назвою та описом з календаря і приховуються за допомогою фільтра пошуку, поки не наближається час їх початку.",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Позначте розмови як конфіденційні в налаштуваннях сповіщень, щоб приховати вміст повідомлень зі списку розмов та сповіщень",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Щоб отримувати пуш-сповіщення під час режиму \"Не турбувати\", позначте розмови як важливі",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Додайте інших учасників до тет-а-тет виклику, щоб створити новий груповий виклик на льоту",
    "- Use threads to keep your chat and discussions organized" : "- Використовуйте теми, щоб упорядкувати чат і дискусії",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Транскрипція в реальному часі тепер доступна під час дзвінка (потрібен ExApp для транскрипції в реальному часі та високопродуктивний бекенд)",
    "_All %n participant_::_All %n participants_" : ["Всі %n учасників","Всі %n учасників","Всі %n учасників","Всі %n учасників"],
    "Talk updates ✅" : "Обговоріть оновлення ✅",
    "Reaction deleted by author" : "Реакцію вилучено автором",
    "{actor} created the conversation" : "{actor} створив(-ла) розмову",
    "You created the conversation" : "Ви створили розмову",
    "System created the conversation" : "Система створила розмову",
    "An administrator created the conversation" : "Адміністратор створив розмову",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} змінив(-ла) назву розмови з \"%1$s\" на \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Ви змінили назву розмови з \"%1$s\" на \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Адміністратор змінив(-ла) назву розмови з \"%1$s\" на \"%2$s\"",
    "{actor} set the description" : "{actor} встановив опис",
    "You set the description" : "Ви встановлюєте опис",
    "An administrator set the description" : "Опис встановив адміністратор",
    "{actor} removed the description" : "{actor} прибрав(-ла) опис",
    "You removed the description" : "Ви вилучили опис",
    "An administrator removed the description" : "Адміністратор прибрав опис",
    "You started a silent call" : "Ти почав мовчазний дзвінок",
    "Outgoing silent call" : "Вихідний тихий дзвінок",
    "{actor} started a silent call" : "{actor} почався тихий дзвінок.",
    "Incoming silent call" : "Вхідний тихий дзвінок",
    "You started a call" : "Ви почали виклик",
    "Outgoing call" : "Вихідний дзвінок",
    "{actor} started a call" : "{actor} розпочав розмову",
    "Incoming call" : "Вхідний дзвінок",
    "{actor} joined the call" : "{actor} приєднався до розмови",
    "You joined the call" : "Ви приєдналися до виклику",
    "{actor} left the call" : "{actor} залишив розмову",
    "You left the call" : "Ви залишили розмову",
    "{actor} unlocked the conversation" : "{actor} розблокував бесіду",
    "You unlocked the conversation" : "Ви розблокували розмову",
    "An administrator unlocked the conversation" : "Адміністратор розблокував розмову",
    "{actor} locked the conversation" : "{actor} заблокував розмову",
    "You locked the conversation" : "Ви заблокували розмову",
    "An administrator locked the conversation" : "Адміністратор заблокував розмову",
    "{actor} limited the conversation to the current participants" : "{actor} обмежив розмову до поточних учасників",
    "You limited the conversation to the current participants" : "Ви обмежили бесіду поточними учасниками",
    "An administrator limited the conversation to the current participants" : "Адміністратор обмежив розмову для поточних учасників",
    "{actor} opened the conversation to registered users" : "{actor} відкрив розмову для зареєстрованих користувачів",
    "You opened the conversation to registered users" : "Ви відкрили розмову для зареєстрованих користувачів",
    "An administrator opened the conversation to registered users" : "Адміністратор відкрив розмову для зареєстрованих користувачів",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} відкрив розмову для зареєстрованих користувачів та користувачів, створених у додатку \"Гості",
    "You opened the conversation to registered users and users created with the Guests app" : "Ви відкрили бесіду для зареєстрованих користувачів і користувачів, створених за допомогою програми \"Гості",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Адміністратор відкрив розмову зареєстрованим користувачам і користувачам, створеним за допомогою програми \"Гості",
    "The conversation is now open to everyone" : "Розмова тепер відкрита для всіх",
    "{actor} opened the conversation to everyone" : "{actor} відкрив бесіду для всіх",
    "You opened the conversation to everyone" : "Ви відкрили розмову для всіх",
    "{actor} restricted the conversation to moderators" : "{actor} обмежив бесіду для модераторів",
    "You restricted the conversation to moderators" : "Ви обмежили розмову модераторами",
    "{actor} started breakout rooms" : "{actor} запустив розділені кімнати",
    "You started breakout rooms" : "{actor} запустили розділені кімнати",
    "{actor} stopped breakout rooms" : "{actor} закрив кімнати обговорення",
    "You stopped breakout rooms" : "Ви закрили кімнати обговорення",
    "{actor} allowed guests" : "{actor} дозволив гостям",
    "You allowed guests" : "Ви дозволили доступ гостям",
    "An administrator allowed guests" : "Адміністратор дозволив гостей",
    "{actor} disallowed guests" : "{actor} заборонив гостей",
    "You disallowed guests" : "Ви заборонили гостям",
    "An administrator disallowed guests" : "Адміністратор заборонив гостям",
    "{actor} set a password" : "{actor} встановив пароль",
    "You set a password" : "Ви встановили пароль",
    "An administrator set a password" : "Адміністратор встановив пароль",
    "{actor} removed the password" : "{actor} вилучив пароль",
    "You removed the password" : "Ви вилучили пароль",
    "An administrator removed the password" : "Адміністратор забрав пароль",
    "{actor} added {user}" : "{actor} додав(-ла) {user}",
    "You joined the conversation" : "Ви приєдналися до розмови",
    "{actor} joined the conversation" : "{actor} приєднався до розмови",
    "You added {user}" : "Ви додали {user}",
    "{actor} added you" : "{actor} додав(-ла) вас",
    "An administrator added you" : "Вас додав адміністратор",
    "An administrator added {user}" : "Адміністратор додав {user}",
    "You left the conversation" : "Ви залишили розмову",
    "{actor} left the conversation" : "{actor} залишив бесіду",
    "{actor} removed {user}" : "{actor} вилучив користувача {user}",
    "You removed {user}" : "Ви вилучили користувача {user}",
    "{actor} removed you" : "{actor} вилучив вас",
    "An administrator removed you" : "Адміністратор вилучив вас",
    "An administrator removed {user}" : "Адміністратор вилучив {user}",
    "{actor} invited {federated_user}" : "{actor} запрошені {federated_user}",
    "You invited {federated_user}" : "Ти запросив {federated_user}",
    "You accepted the invitation" : "Ви прийняли запрошення",
    "{actor} invited you" : "{actor} запросив тебе.",
    "An administrator invited you" : "Вас запросив адміністратор",
    "An administrator invited {federated_user}" : "Адміністратор запросив {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} прийняв запрошення",
    "{actor} removed {federated_user}" : "{actor} вилучив(-ла) {federated_user}",
    "You removed {federated_user}" : "Ви вилучили {federated_user}",
    "You declined the invitation" : "Ви відхилили запрошення",
    "An administrator removed {federated_user}" : "Адміністратор вилучив {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} відхилив запрошення",
    "{actor} added group {group}" : "{actor} додано групу {group}",
    "You added group {group}" : "Ви додали групу {group}",
    "An administrator added group {group}" : "Адміністратором додано групу {group}",
    "{actor} removed group {group}" : "{actor} вилучив(-ла) групу {group}",
    "You removed group {group}" : "Ви вилучили групу {group}",
    "An administrator removed group {group}" : "Адміністратор вилучив групу {group}",
    "{actor} added team {circle}" : "{actor} додано команду {circle}",
    "You added team {circle}" : "Ви додали команду {circle}",
    "An administrator added team {circle}" : "Адміністратор додав команду {circle}",
    "{actor} removed team {circle}" : "{actor} видалена команда {circle}",
    "You removed team {circle}" : "Ви видалили команду {circle}",
    "An administrator removed team {circle}" : "Команда видалена адміністратором {circle}",
    "{actor} added {phone}" : "{actor} додано {phone}",
    "You added {phone}" : "Ви додали {phone}",
    "An administrator added {phone}" : "Адміністратор додав {phone}",
    "{actor} removed {phone}" : "{actor} видалено {phone}",
    "You removed {phone}" : "Ви видалили {phone}",
    "An administrator removed {phone}" : "Адміністратор видалив {phone}",
    "{actor} promoted {user} to moderator" : "{actor} призначив {user} модератором ",
    "You promoted {user} to moderator" : "Ви призначили {user} модератором ",
    "{actor} promoted you to moderator" : "{actor} призначив вас модератором",
    "An administrator promoted you to moderator" : "Адміністратор призначив вас модератором",
    "An administrator promoted {user} to moderator" : "Адміністратор призначив {user} модератором",
    "{actor} demoted {user} from moderator" : "{actor} позбавив {user} статусу модератора ",
    "You demoted {user} from moderator" : "Ви позбавили {user} статусу модератора",
    "{actor} demoted you from moderator" : "{actor} позбавив вас статусу модератора",
    "An administrator demoted you from moderator" : "Адміністратор позбавив вас статусу модератора",
    "An administrator demoted {user} from moderator" : "Адміністратор позбавив {user} статусу модератора",
    "{actor} shared a file which is no longer available" : "{actor} поділив(-ла-)ся файлом, який більше не доступний ",
    "You shared a file which is no longer available" : "Ви поділилися файлом, який більше не доступний",
    "File shares are currently not supported in federated conversations" : "Файлові ресурси наразі не підтримуються в об'єднаних розмовах",
    "The shared location is malformed" : "Спільне місце розташування сформовано неправильно",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} налаштував Matterbridge для синхронізації цієї розмови з іншими чатами ",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Ви налаштували Matterbridge для синхронізації цієї розмови з іншими чатами ",
    "{actor} created thread {title}" : "{actor} створив потік {title}",
    "You created thread {title}" : "Ви створили потік {title}",
    "{actor} renamed thread {title}" : "{actor} перейменував потік {title}",
    "You renamed thread {title}" : "Ви перейменували потік {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} оновив(-ла) конфігурацію Matterbridge ",
    "You updated the Matterbridge configuration" : "Ви оновили конфігурацію Matterbridge ",
    "{actor} removed the Matterbridge configuration" : "{actor} вилучив(-ла) конфігурацію Matterbridge ",
    "You removed the Matterbridge configuration" : "Ви вилучили конфігурацію Matterbridge",
    "{actor} started Matterbridge" : "{actor} запустив(ла) систему обміну повідомленнями Matterbridge",
    "You started Matterbridge" : "Ви запустив(ла) систему обміну повідомленнями Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} зупинив(ла) систему обміну повідомленнями Matterbridge",
    "You stopped Matterbridge" : "Ви зупинив(ла) систему обміну повідомленнями Matterbridge",
    "{actor} deleted a message" : "{actor} вилучив(-ла) повідомлення",
    "You deleted a message" : "Ви вилучили повідомлення",
    "{actor} edited a message" : "{actor} відредагував повідомлення",
    "You edited a message" : "Ви відредагували повідомлення",
    "{actor} deleted a reaction" : "{actor} прибрав(-ла) реакцію",
    "You deleted a reaction" : "Ви прибрали реакцію",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Ви встановили термін дії повідомлення у %n тижні(-в)","Ви встановили термін дії повідомлення у %n тижні(-в)","Ви встановили термін дії повідомлення у %n тижні(-в)","Ви встановили термін дії повідомлення у %n тижні(-в)"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Ви встановили термін дії повідомлення у %n дні(-в)","Ви встановили термін дії повідомлення у %n дні(-в)","Ви встановили термін дії повідомлення у %n дні(-в)","Ви встановили термін дії повідомлення у %n дні(-в)"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Ви встановили термін дії повідомлення у %n годин(-у,и)","Ви встановили термін дії повідомлення у %n годин(-у,и)","Ви встановили термін дії повідомлення у %n годин(-у,и)","Ви встановили термін дії повідомлення у %n годин(-у,и)"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Ви встановили термін дії повідомлення у %n хвилин(-у,и)","Ви встановили термін дії повідомлення у %n хвилин(-у,и)","Ви встановили термін дії повідомлення у %n хвилин(-у,и)","Ви встановили термін дії повідомлення у %n хвилин(-у,и)"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} встановити термін дії повідомлення у %n тижні(-в)","{actor} встановити термін дії повідомлення у %n тижні(-в)","{actor} встановити термін дії повідомлення у %n тижні(-в)","{actor} встанов(-ла) термін дії повідомлення у %n тижні(-в)"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} встановити термін дії повідомлення у %n дні(-в)","{actor} встановити термін дії повідомлення у %n дні(-в)","{actor} встановити термін дії повідомлення у %n дні(-в)","{actor} встанов(-ла) термін дії повідомлення у %n дні(-в)"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} встановити термін дії повідомлення у %n годин(-у,и)","{actor} встановити термін дії повідомлення у %n годин(-у,и)","{actor} встановити термін дії повідомлення у %n годин(-у,и)","{actor} встанов(-ла) термін дії повідомлення у %n годин(-у,и)"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} встановити термін дії повідомлення у %n хвилин(-у,и)","{actor} встановити термін дії повідомлення у %n хвилин(-у,и)","{actor} встановити термін дії повідомлення у %n хвилин(-у,и)","{actor} встанов(-ла) термін дії повідомлення у %n хвилин(-у,и)"],
    "{actor} disabled message expiration" : "{actor} вимкнув закінчення терміну дії повідомлення",
    "You disabled message expiration" : "Ви вимкнули закінчення терміну дії повідомлення",
    "{actor} cleared the history of the conversation" : "{actor} очистив(ла) історію розмови",
    "You cleared the history of the conversation" : "Ви очистили історію розмови",
    "{actor} set the conversation picture" : "{actor} встанов(ла) картинку розмови",
    "You set the conversation picture" : "Ви встановили картинку розмови",
    "{actor} removed the conversation picture" : "{actor} прибрав(-ла) зображення розмови",
    "You removed the conversation picture" : "Ви вилучили зображення розмови",
    "{actor} ended the poll {poll}" : "{actor} завершив опитування {poll}",
    "You ended the poll {poll}" : "Ви завершили опитування {poll}",
    "{actor} started the video recording" : "{actor} запустив відеозапис",
    "You started the video recording" : "Ви запустили відеозапис",
    "{actor} stopped the video recording" : "{actor} зупинив(ла) запис відео",
    "You stopped the video recording" : "Ви зупинили запис відео",
    "{actor} started the audio recording" : "{actor} запустив аудіозапис",
    "You started the audio recording" : "Ви запустили аудіозапис",
    "{actor} stopped the audio recording" : "{actor} зупинив аудіозапис",
    "You stopped the audio recording" : "Ви зупинили аудіозапис",
    "The recording failed" : "Запис не вдалося виконати",
    "Someone voted on the poll {poll}" : "Хтось проголосував на опитуванні {poll}",
    "Message deleted by author" : "Автор вилучив(-ла) повідомлення",
    "Message deleted by {actor}" : "{actor} вилучив(-ла) повідомлення",
    "Message deleted by you" : "Ви вилучили повідомлення",
    "Deleted user" : "Вилучений користувач",
    "Unknown number" : "Невідомий номер",
    "Administration" : "Адміністрування",
    "System" : "Система",
    "%s (guest)" : "%s(гість)",
    "Missed call" : "Пропущений дзвінок.",
    "Unanswered call" : "Дзвінок без відповіді",
    "Call ended (Duration {duration})" : "Дзвінок завершено (Тривалість {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Дзвінок було завершено, оскільки він досягнув максимальної тривалості (Тривалість {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} завершив розмову (Тривалість {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Дзвінок з гостем %n було завершено, оскільки він досягнув максимальної тривалості (Тривалість {duration})","Розмова з %n гостями була завершена, оскільки вона досягла максимальної тривалості (Тривалість {duration})","Розмова з %n гостями була завершена, оскільки вона досягла максимальної тривалості (Тривалість {duration})","Розмова з %n гостями була завершена, оскільки вона досягла максимальної тривалості (Тривалість {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Дзвінок з гостем %n завершено (Тривалість {duration})","Закінчилася розмова з %n гостями (Тривалість {duration})","Закінчилася розмова з %n гостями (Тривалість {duration})","Закінчилася розмова з %n гостями (Тривалість {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} закінчив розмову з %n гостем (Duration {duration})","{actor} закінчив розмову з %n гостями (Duration {duration})","{actor} закінчив розмову з %n гостями (Duration {duration})","{actor} закінчив розмову з %n гостями (Duration {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Дзвінок з {user1} було завершено, оскільки було досягнуто максимальної тривалості дзвінка (Тривалість {duration})",
    "Call with {user1} ended (Duration {duration})" : "Дзвінок з {user1} закінчився (Тривалість {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} завершив виклик за участю {user1} (Тривалість {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Дзвінок з {user1} та {user2} було завершено, оскільки він досягнув максимальної тривалості (Тривалість {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Дзвінок з {user1} та {user2} закінчився (тривалість {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} завершив виклик з {user1} та {user2} (Тривалість {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Дзвінок з {user1}, {user2} та {user3} було завершено, оскільки він досягнув максимальної тривалості (тривалість {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Дзвінок з {user1}, {user2} та {user3} закінчився (тривалість {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} завершив виклик з {user1}, {user2} та {user3} (Duration {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Дзвінок з {user1}, {user2}, {user3} та {user4} було завершено, оскільки він досягнув максимальної тривалості (тривалість {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Дзвінок з {user1}, {user2}, {user3} та {user4} закінчився (тривалість {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} завершив(-ла) виклик з {user1}, {user2}, {user3} та {user4} (Тривалість {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Дзвінок з абонентами {user1}, {user2}, {user3}, {user4} та {user5} було завершено, оскільки було досягнуто максимальної тривалості дзвінка (Тривалість {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Дзвінок з {user1}, {user2}, {user3}, {user4} та {user5} закінчився (Тривалість {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} завершив виклик з {user1}, {user2}, {user3}, {user4} та {user5} (Тривалість {duration})",
    "Message of {user} in {conversation}" : "Повідомлення {user} у {conversation}",
    "Message of {user}" : "Повідомлення від {user}",
    "Message of a deleted user in {conversation}" : "Повідомлення видаленого користувача в {conversation}",
    "Talk conversations" : "Розмови",
    "Call %s" : "Телефонуйте %s",
    "An error occurred. Please contact your administrator." : "Виникла помилка. Будь ласка, зверніться до вашого адміністратора.",
    "Storage quota exceeded" : "Перевищено дозволений обсяг даних для збереження",
    "File not found" : "Файл не знайдено",
    "File is not shared, or shared but not with the user" : "До файлу не надано спільний доступ або надано, але не користувачеві",
    "No account available to delete." : "Обліковий запис недоступний для видалення.",
    "Poll" : "Опитування",
    "Password needs to be set" : "Необхідно встановити пароль",
    "Uploading the file failed" : "Не вдалося завантажити файл",
    "No image file provided" : "Файл зображення не надано",
    "File is too big" : "Файл занадто великий",
    "Invalid file provided" : "Надано невірний файл",
    "Invalid image" : "Недійсне зображення",
    "Unknown filetype" : "Невідомий тип файлу",
    "Talk mentions" : "Резюме із Talk",
    "More conversations" : "Більше розмов",
    "Say hi to your friends and colleagues!" : "Привітайтеся з вашими друзями та колегами!",
    "No unread mentions" : "Немає непрочитаних згадок",
    "Call in progress" : "Триває виклик",
    "You were mentioned" : "Про вас згадували",
    "Write to conversation" : "Написати у розмові",
    "Writes event information into a conversation of your choice" : "Додає інформацію про подію в розмову на ваш вибір",
    "Missing email field in header line" : "Відсутнє поле електронної пошти в заголовку",
    "Following lines are invalid: %s" : "Наступні рядки є невірними: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s запросив вас до розмови \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Вас запросили на розмову \"%s\".",
    "Conversation invitation" : "Запрошення до розмови",
    "Scheduled time" : "Запланований час",
    "Description" : "Опис",
    "You can also dial-in via phone with the following details" : "Ви також можете підключитися за телефоном, вказавши такі дані",
    "Dial-in information" : "Інформація для входу в систему",
    "Meeting ID" : "Ідентифікатор зустрічі",
    "Your PIN" : "Ваш пін-код.",
    "Click the button below to join the lobby now." : "Натисніть кнопку нижче, щоб приєднатися до лобі зараз.",
    "Click the link below to join the lobby now." : "Натисніть на посилання нижче, щоб приєднатися до лобі зараз.",
    "Join lobby for \"%s\"" : "Приєднуйтесь до лобі для \"%s\"",
    "Click the button below to join the conversation now." : "Натисніть кнопку нижче, щоб приєднатися до розмови зараз.",
    "Click the link below to join the conversation now." : "Перейдіть за посиланням нижче, щоб приєднатися до дискусії прямо зараз.",
    "Join \"%s\"" : "Приєднайте \"%s\"",
    "Meeting" : "Зустріч",
    "Password request: %s" : "Запит пароля:%s",
    "Private conversation" : "Приватна розмова",
    "Deleted user (%s)" : "Вилучений користувач (%s)",
    "Failed to upload call recording" : "Не вдалося завантажити запис розмови",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Серверу запису не вдалося завантажити запис дзвінка {call}. Будь ласка, зверніться до адміністрації.",
    "Share to chat" : "Поділитися в чаті",
    "Dismiss notification" : "Скасувати сповіщення",
    "Call recording now available" : "Відтепер доступний запис дзвінків",
    "The recording for the call in {call} was uploaded to {file}." : "Запис дзвінка в {call} було завантажено до {file}.",
    "Transcript now available" : "Тепер доступна стенограма",
    "The transcript for the call in {call} was uploaded to {file}." : "Розшифровку дзвінка в {call} було завантажено до {file}.",
    "Failed to transcript call recording" : "Не вдалося розшифрувати запис розмови",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Серверу не вдалося розшифрувати запис за адресою {file} для дзвінка в {call}. Будь ласка, зверніться до адміністрації.",
    "Call summary now available" : "Звіт про дзвінки тепер доступний",
    "The summary for the call in {call} was uploaded to {file}." : "Підсумки конкурсу {call} були завантажені на сайт {file}.",
    "Failed to summarize call recording" : "Не вдалося підсумувати запис розмови",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Сервер не зміг підсумувати запис на {file} для дзвінка на {call}. Будь ласка, зверніться до адміністрації.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} запрошує вас приєднатися до {roomName} на {remoteServer}",
    "Accept" : "Прийняти",
    "Decline" : "Відхилити",
    "{user1} invited you to a federated conversation" : "{user1} запросили вас на федеративну розмову",
    "Someone reacted" : "Хтось відреагував",
    "New message" : "Нове повідомлення",
    "Reminder" : "Нагадування",
    "Someone mentioned you" : "Хтось згадував про вас.",
    "Notification" : "Сповіщення",
    "Someone reacted in a private conversation" : "Хтось відреагував у приватній розмові",
    "You received a message in a private conversation" : "Ви отримали повідомлення у приватній розмові",
    "Reminder in a private conversation" : "Нагадування в приватній розмові",
    "Someone mentioned you in a private conversation" : "Хтось згадав вас у приватній розмові",
    "Notification in a private conversation" : "Сповіщення в приватній розмові",
    "Reminder: You in {call}" : "Нагадування: Ви в  {call}",
    "Reminder: {user} in {call}" : "Нагадування: {user} в {call}",
    "Reminder: Deleted user in {call}" : "Нагадування: Видалено користувача в {call}",
    "Reminder: {guest} (guest) in {call}" : "Нагадування: {guest} (guest) у {call}",
    "Reminder: Guest in {call}" : "Нагадування: Гість у {call}",
    "{user} reacted with {reaction}" : "{user} прореагував з {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} прореагував з {reaction} у {call}",
    "Deleted user reacted with {reaction} in {call}" : "Видалений користувач відреагував на {reaction} у {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (guest) відреагував(ла) на {reaction} у {call}",
    "Guest reacted with {reaction} in {call}" : "Гість відреагував {reaction} у {call}",
    "{user} in {call}" : "{user} у {call}",
    "Deleted user in {call}" : "Вилучено користувача у {call}",
    "{guest} (guest) in {call}" : "{guest} (guest) у {call}",
    "Guest in {call}" : "Гість у {call}",
    "{user} sent you a private message" : "{user} відправив(ла) вам приватне повідомлення",
    "{user} sent a message in conversation {call}" : "{user} надіслав(ла) повідомлення в розмові {call}",
    "A deleted user sent a message in conversation {call}" : "Видалений користувач надіслав(ла) повідомлення в розмові {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (guest) надіслав(ла) повідомлення в розмові {call}",
    "A guest sent a message in conversation {call}" : "Гість надіслав повідомлення в розмові {call}.",
    "{user} replied to your private message" : "{user} відповів(ла) на ваше особисте повідомлення",
    "{user} replied to your message in conversation {call}" : "{user} відповів(ла) на ваше повідомлення у розмові {call}.",
    "A deleted user replied to your message in conversation {call}" : "Видалений користувач відповів(ла) на ваше повідомлення в розмові {call}.",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (guest) відповів(ла) на ваше повідомлення у розмові {call}.",
    "A guest replied to your message in conversation {call}" : "Гість відповів(ла) на ваше повідомлення у розмові {call}.",
    "Reminder: You in private conversation {call}" : "Нагадування: Ви в приватній розмові {call}",
    "Reminder: A deleted user in private conversation {call}" : "Нагадування: Видалений користувач у приватній розмові {call}",
    "Reminder: {user} in private conversation" : "Нагадування: {user} у приватній розмові",
    "Reminder: You in conversation {call}" : "Нагадування: Ви в розмові {call}",
    "Reminder: {user} in conversation {call}" : "Нагадування: {user} в розмові {call}",
    "Reminder: A deleted user in conversation {call}" : "Нагадування: Видалений користувач у розмові {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Нагадування: {guest} (guest) у розмові {call}",
    "Reminder: A guest in conversation {call}" : "Нагадування: Гість у розмові {call}.",
    "{user} reacted with {reaction} to your private message" : "{user} відреагував(ла) {reaction} на ваше приватне повідомлення",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} відреагував {reaction} на ваше повідомлення у розмові {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Видалений користувач відреагував {reaction} на ваше повідомлення у розмові {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (guest) відреагував(ла) {reaction} на ваше повідомлення у розмові {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Гість відреагував {reaction} на ваше повідомлення у розмові {call}.",
    "{user} mentioned you in a private conversation" : "{user} згадав вас у приватній розмові",
    "{user} mentioned group {group} in conversation {call}" : "{user} згадав(ла) групу {group} в розмові {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} згадували команду {team} у розмові {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} згадав(ла) усіх у розмові {call}",
    "{user} mentioned you in conversation {call}" : "{user} згадував(ла) вас у розмові {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Видалений користувач згадав(ла) групу {group}  у розмові {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Видалений користувач згадав команду {team} у розмові {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Видалений користувач згадав усіх у розмові {call}.",
    "A deleted user mentioned you in conversation {call}" : "Користувач, якого було вилучено, згадав вас у розмові {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (гість) згадав групу {group} в розмові {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (гість) згадав у розмові команду {team} {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (гість) згадав усіх у розмові {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (гість) згадав вас у розмові {call}",
    "A guest mentioned group {group} in conversation {call}" : "Гість згадав групу  {group} у розмові {call}",
    "A guest mentioned team {team} in conversation {call}" : "У розмові гість згадав команду {team} {call}",
    "A guest mentioned everyone in conversation {call}" : "Гість згадав усіх у розмові {call}",
    "A guest mentioned you in conversation {call}" : "Гість згадав вас у розмові {call}",
    "View message" : "Переглянути повідомлення",
    "Dismiss reminder" : "Скасувати нагадування ",
    "View chat" : "Перегляд чату",
    "{user} invited you to a group conversation: {call}" : "{user} запросив(-ла) вас до групової розмови: {call}",
    "Join call" : "Приєднатися",
    "Answer call" : "Відповісти на виклик",
    "{user} would like to talk with you" : "{user} хотів(-ла) би поговорити з вами",
    "Call back" : "Передзвони мені.",
    "You missed a call from {user}" : "Ви пропустили виклик від {user}",
    "Accept call" : "Прийняти виклик",
    "Incoming phone call from {call}" : "Вхідний дзвінок від {call}",
    "You missed a phone call from {call}" : "Ви пропустили телефонний дзвінок від {call}",
    "A group call has started in {call}" : "Групову розмову розпочато у {call}",
    "You missed a group call in {call}" : "Ви пропустили груповий виклик у {call}",
    "{email} is requesting the password to access {file}" : "{email} запитує пароль для доступу до {file}",
    "{email} tried to request the password to access {file}" : "{email} намагався запросити пароль для доступу до {file}",
    "Someone is requesting the password to access {file}" : "Хтось запитує пароль для доступу до {file}",
    "Someone tried to request the password to access {file}" : "Хтось намагався запитати пароль для доступу до {file}",
    "Open settings" : "Відкрити налаштування",
    "Hosted signaling server added" : "Додано виділений сервер сигналізації",
    "The hosted signaling server is now configured and will be used." : "Виділений сервер сигналізації налаштований і готовий до використання.",
    "Hosted signaling server removed" : "Видалено хостинговий сервер сигналізації",
    "The hosted signaling server was removed and will not be used anymore." : "Виділений сервер сигналізації було вилучено і більше не буде використовуватися.",
    "Hosted signaling server changed" : "Змінено виділений сервер сигналізації",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Обліковий запис виділеного сервера сигналізації змінив статус з \"{oldstatus}\" на \"{newstatus}\".",
    "pending" : "на розгляді",
    "active" : "активний",
    "expired" : "закінчився",
    "blocked" : "заблоковано",
    "error" : "помилка",
    "The certificate of {host} expires in {days} days" : "Термін дії сертифіката {host} закінчується через {days} дні(-в)",
    "The certificate of {host} expired" : "Термін дії сертифіката {host} закінчився",
    "Contact via Talk" : "Зв'яжіться з нами через Talk",
    "Open Talk" : "Відкрити Talk",
    "Default" : "За замовчуванням",
    "Presentation" : "Презентація",
    "Webinar" : "Вебінар",
    "Conversations" : "Розмови",
    "Messages in current conversation" : "Повідомлення в поточній розмові",
    "{user}" : "{user}",
    "Messages" : "Повідомлення",
    "{user} in {conversation}" : "{user} в {conversation}",
    "Messages in other conversations" : "Повідомлення в інших розмовах",
    "One-to-one rooms always need to show the other users avatar" : "У кімнатах один на один завжди потрібно показувати аватарку іншого користувача",
    "Invalid emoji character" : "Неправильний символ емодзі",
    "Invalid background color" : "Неправильний колір фону",
    "Avatar image is not square" : "Зображення аватара не квадратне",
    "Room {number}" : "Кімната {number}",
    "Favorites" : "Із зірочкою",
    "Other" : "Інші",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Не вдалося запросити пробну версію, оскільки сервер недоступний. Будь ласка, спробуйте пізніше.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Виникла проблема з авторизацією цього сервера хмари. Можливо, він недоступний ззовні, що не дозволяє здійснити перевірити за URL.",
    "Something unexpected happened." : "Сталося щось непередбачуване.",
    "The URL is invalid." : "URL-адреса є недійсною.",
    "An HTTPS URL is required." : "Необхідно вказати  HTTPS URL.",
    "The email address is invalid." : "Адреса електронної пошти є недійсною.",
    "The language is invalid." : "Мова є недійсною.",
    "The country is invalid." : "Країна є недійсною.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Існує проблема із запитом на випробування. Будь ласка, перевірте свої журнали для отримання додаткової інформації.",
    "Too many requests are send from your servers address. Please try again later." : "Занадто багато запитів відправлено з адреси вашого сервера. Будь ласка, спробуйте пізніше.",
    "There is already a trial registered for this Nextcloud instance." : "Для цього примірника сервера хмари Nextcloud вже зареєстровано пробне використання.",
    "Something unexpected happened. Please try again later." : "Сталося щось непередбачуване. Будь ласка, спробуйте пізніше.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Не вдалося надіслати запит на пробну версію, тому що пробний сервер поводився некоректно. Будь ласка, спробуйте пізніше.",
    "Trial requested but failed to get account information. Please check back later." : "Запитано пробну версію, але не вдалося отримати інформацію про обліковий запис. Будь ласка, перевірте пізніше.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Виникла проблема із авторизацією цього запиту. Можливо, він недоступний ззовні, що не дозволяє перевірити його URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Не вдалося отримати інформацію про обліковий запис через неправильну роботу пробного сервера. Будь ласка, перевірте пізніше.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Існує проблема з отриманням інформації про обліковий запис. Будь ласка, перевірте свої журнали для отримання додаткової інформації.",
    "There is no such account registered." : "Такого облікового запису не зареєстровано.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Не вдалося отримати інформацію про обліковий запис, оскільки пробний сервер недоступний. Будь ласка, перевірте пізніше.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Не вдалося вилучити обліковий запис сервера сигналізації. Спробуйте пізніше.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Не вдалося вилучити обліковий запис, оскільки отимано неправильний відгук від пробного сервера. Спробуйте пізніше.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Виникла проблема з вилученням облікового запису. Будь ласка, перевірте журнали, щоб отримати додаткову інформацію.",
    "Too many requests are sent from your servers address. Please try again later." : "Занадто багато запитів відправлено з адреси вашого сервера. Будь ласка, повторіть спробу пізніше.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Не вдалося вилучити обліковий запис, оскільки пробний сервер недоступний. Спробуйте пізніше.",
    "Note to self" : "Примітка для себе",
    "A place for your private notes, thoughts and ideas" : "Місце для ваших особистих нотаток, думок та ідей",
    "Transcript is AI generated and may contain mistakes" : "Транскрипт згенерований штучним інтелектом і може містити помилки",
    "Summary is AI generated and may contain mistakes" : "Резюме згенероване штучним інтелектом і може містити помилки",
    "Let's get started!" : "Почнімо!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** — це безпечна, самостійно розміщена комунікаційна платформа, яка безперешкодно інтегрується в екосистему Nextcloud.\n\n#### Основні функції Nextcloud Talk:\n\n* Чат і обмін повідомленнями в приватних і групових чатах\n* Голосові та відеодзвінки\n* Обмін файлами та інтеграція з іншими додатками Nextcloud\n* Налаштовувані параметри розмов, модерація та контроль конфіденційності\n* Веб, настільні та мобільні пристрої (iOS та Android)\n* Приватне та безпечне спілкування\n\nДізнайтеся більше в [документації для користувачів](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Ласкаво просимо до Nextcloud Talk\n\nNextcloud Talk — це приватний і потужний месенджер, інтегрований із Nextcloud. Чатуйте в приватних або групових розмовах, співпрацюйте за допомогою голосових і відеодзвінків, організовуйте вебінари та події, налаштовуйте свої розмови та багато іншого.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Форматування тексту для створення багатоформатних повідомлень\n\nУ Nextcloud Talk ви можете використовувати синтаксис Markdown для форматування своїх повідомлень. Наприклад, застосовувати **жирний** або *курсивний* шрифт, або `виділяти текст як код`. Ви навіть можете створювати таблиці та додавати заголовки до свого тексту.\n\nПотрібно виправити помилку або змінити форматування? Відредагуйте своє повідомлення, натиснувши «Редагувати повідомлення» в меню повідомлення.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Додавання вкладень та посилань\n\nДодавайте файли з Nextcloud Hub за допомогою кнопки «+». Діліться елементами з Files та різних додатків Nextcloud. Деякі додатки навіть підтримують інтерактивні віджети, наприклад, додаток Text.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Нехай розмови течуть: згадуйте користувачів, реагуйте на повідомлення та багато іншого\n\nВи можете згадати всіх учасників розмови, використовуючи %s або згадати конкретних учасників, набравши «@» і вибравши їх ім'я зі списку.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Ви можете відповідати на повідомлення, пересилати їх в інші чати та іншим користувачам або копіювати їхній вміст.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Робіть більше з Smart Picker\n\nПросто введіть «/» або перейдіть до меню «+», щоб відкрити Smart Picker, де ви можете додавати різний контент до своїх повідомлень. Ви можете налаштувати Smart Picker, щоб додавати елементи з додатків Nextcloud, GIF-файли, місця на карті, контент, створений штучним інтелектом, та багато іншого.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Керування налаштуваннями розмов\n\nУ меню розмов ви можете отримати доступ до різних налаштувань для керування розмовами, таких як:\n* Редагування інформації про розмову\n* Керування сповіщеннями\n* Застосування численних правил модерації\n* Налаштування доступу та безпеки\n* Увімкнення ботів\n* та багато іншого!",
    "Andorra" : "Андорра",
    "United Arab Emirates" : "Об'єднані Арабські Емірати",
    "Afghanistan" : "Афганістан",
    "Antigua and Barbuda" : "Антигуа та Барбуда",
    "Anguilla" : "Ангілья ",
    "Albania" : "Албанія ",
    "Armenia" : "Вірменія",
    "Angola" : "Ангола ",
    "Antarctica" : "Антарктида",
    "Argentina" : "Аргентина ",
    "American Samoa" : "Американське Самоа ",
    "Austria" : "Австрія ",
    "Australia" : "Австралія ",
    "Aruba" : "Аруба ",
    "Åland Islands" : "Аландські острови ",
    "Azerbaijan" : "Азербайджан",
    "Bosnia and Herzegovina" : "Боснія і Герцеговина",
    "Barbados" : "Барбадос",
    "Bangladesh" : "Бангладеш",
    "Belgium" : "Бельгія ",
    "Burkina Faso" : "Буркіна-Фасо",
    "Bulgaria" : "Болгарія ",
    "Bahrain" : "Бахрейн ",
    "Burundi" : "Бурунді ",
    "Benin" : "Бенін",
    "Saint Barthélemy" : "Сен-Бартелемі ",
    "Bermuda" : "Бермудські острови",
    "Brunei Darussalam" : "Бруней",
    "Bolivia, Plurinational State of" : "Болівія",
    "Bonaire, Sint Eustatius and Saba" : "Бонайре, Сінт-Естатіус і Саба",
    "Brazil" : "Бразилія ",
    "Bahamas" : "Багамські острови",
    "Bhutan" : "Бутан ",
    "Bouvet Island" : "Острів Буве",
    "Botswana" : "Ботсвана ",
    "Belarus" : "Білорусь",
    "Belize" : "Беліз ",
    "Canada" : "Канада",
    "Cocos (Keeling) Islands" : "Кокосові (Кілінгові) острови ",
    "Congo, the Democratic Republic of the" : "Демократична Республіка Конґо",
    "Central African Republic" : "Центральноафриканська Республіка ",
    "Congo" : "Конго ",
    "Switzerland" : "Швейцарія ",
    "Côte d'Ivoire" : "Кот-д'Івуар ",
    "Cook Islands" : "Острови Кука",
    "Chile" : "Чилі ",
    "Cameroon" : "Камерун ",
    "China" : "Китай ",
    "Colombia" : "Колумбія ",
    "Costa Rica" : "Коста-Ріка ",
    "Cuba" : "Куба ",
    "Cabo Verde" : "Кабо-Верде",
    "Curaçao" : "Кюрасао",
    "Christmas Island" : "Острів Різдва ",
    "Cyprus" : "Кіпр ",
    "Czechia" : "Чехія ",
    "Germany" : "Німеччина ",
    "Djibouti" : "Джибуті ",
    "Denmark" : "Данія ",
    "Dominica" : "Домініка ",
    "Dominican Republic" : "Домініканська Республіка ",
    "Algeria" : "Алжир",
    "Ecuador" : "Еквадор",
    "Estonia" : "Естонія",
    "Egypt" : "Єгипет",
    "Western Sahara" : "Західна Сахара ",
    "Eritrea" : "Еритрея",
    "Spain" : "Іспанія",
    "Ethiopia" : "Ефіопія",
    "Finland" : "Фінляндія",
    "Fiji" : "Фіджі",
    "Falkland Islands (Malvinas)" : "Фолклендські (Мальвінські) острови ",
    "Micronesia, Federated States of" : "Мікронезія",
    "Faroe Islands" : "Фарерські острови ",
    "France" : "Франція",
    "Gabon" : "Габон",
    "United Kingdom of Great Britain and Northern Ireland" : "Сполучене Королівство Великої Британії та Північної Ірландії ",
    "Grenada" : "Гренада",
    "Georgia" : "Грузія",
    "French Guiana" : "Французька Гвіана ",
    "Guernsey" : "Гернсі",
    "Ghana" : "Гана",
    "Gibraltar" : "Гібралтар",
    "Greenland" : "Гренландія",
    "Gambia" : "Гамбія",
    "Guinea" : "Гвінея",
    "Guadeloupe" : "Гваделупа",
    "Equatorial Guinea" : "Екваторіальна Гвінея ",
    "Greece" : "Греція",
    "South Georgia and the South Sandwich Islands" : "Південна Георгія та Південні Сандвічеві острови ",
    "Guatemala" : "Гватемала",
    "Guam" : "Гуам",
    "Guinea-Bissau" : "Гвінея-Бісау ",
    "Guyana" : "Гайана",
    "Hong Kong" : "Гонконг",
    "Heard Island and McDonald Islands" : "Острови Герд і Макдональд",
    "Honduras" : "Гондурас",
    "Croatia" : "Хорватія",
    "Haiti" : "Гаїті",
    "Hungary" : "Угорщина",
    "Indonesia" : "Індонезія",
    "Ireland" : "Ірландія",
    "Israel" : "Ізраїль",
    "Isle of Man" : "Острів Мен",
    "India" : "Індія",
    "British Indian Ocean Territory" : "Британська територія в Індійському океані ",
    "Iraq" : "Ірак",
    "Iran, Islamic Republic of" : "Ісламська Республіка Іран",
    "Iceland" : "Ісландія",
    "Italy" : "Італія",
    "Jersey" : "Джерсі",
    "Jamaica" : "Ямайка",
    "Jordan" : "Йорданія",
    "Japan" : "Японія",
    "Kenya" : "Кенія",
    "Kyrgyzstan" : "Киргизстан",
    "Cambodia" : "Камбоджа",
    "Kiribati" : "Кірибаті",
    "Comoros" : "Коморські острови",
    "Saint Kitts and Nevis" : "Сент-Кіттс і Невіс",
    "Korea, Democratic People's Republic of" : "Корейська Народно-Демократична Республіка Кореї",
    "Korea, Republic of" : "Корея, Республіка ",
    "Kuwait" : "Кувейт",
    "Cayman Islands" : "Кайманові острови ",
    "Kazakhstan" : "Казахстан",
    "Lao People's Democratic Republic" : "Лаоська Народно-Демократична Республіка",
    "Lebanon" : "Ліван",
    "Saint Lucia" : "Сент-Люсія ",
    "Liechtenstein" : "Ліхтенштейн",
    "Sri Lanka" : "Шрі-Ланка ",
    "Liberia" : "Ліберія",
    "Lesotho" : "Лесото",
    "Lithuania" : "Литва",
    "Luxembourg" : "Люксембург",
    "Latvia" : "Латвія",
    "Libya" : "Лівія",
    "Morocco" : "Марокко",
    "Monaco" : "Монако",
    "Moldova, Republic of" : "Молдова",
    "Montenegro" : "Чорногорія",
    "Saint Martin (French part)" : "Сен-Мартен (французька частина) ",
    "Madagascar" : "Мадагаскар",
    "Marshall Islands" : "Маршаллові острови",
    "North Macedonia" : "Північна Македонія ",
    "Mali" : "Малі",
    "Myanmar" : "М'янма",
    "Mongolia" : " Монголія ",
    "Macao" : "Макао",
    "Northern Mariana Islands" : "Північні Маріанські острови",
    "Martinique" : "Мартиніка",
    "Mauritania" : "Мавританія",
    "Montserrat" : "Монтсеррат",
    "Malta" : "Мальта",
    "Mauritius" : "Маврикій",
    "Maldives" : "Мальдіви",
    "Malawi" : "Малаві",
    "Mexico" : "Мексика",
    "Malaysia" : "Малайзія",
    "Mozambique" : "Мозамбік",
    "Namibia" : "Намібія",
    "New Caledonia" : "Нова Каледонія ",
    "Niger" : "Нігер",
    "Norfolk Island" : "Острів Норфолк ",
    "Nigeria" : "Нігерія",
    "Nicaragua" : "Нікарагуа",
    "Netherlands" : "Нідерланди",
    "Norway" : "Норвегія",
    "Nepal" : "Непал",
    "Nauru" : "Науру",
    "Niue" : "Ніуе",
    "New Zealand" : "Нова Зеландія ",
    "Oman" : "Оман",
    "Panama" : "Панама",
    "Peru" : "Перу",
    "French Polynesia" : "Французька Полінезія ",
    "Papua New Guinea" : "Папуа-Нова Гвінея",
    "Philippines" : "Філіппіни",
    "Pakistan" : "Пакистан",
    "Poland" : "Польща",
    "Saint Pierre and Miquelon" : "Сен-П'єр і Мікелон ",
    "Pitcairn" : "Піткерн",
    "Puerto Rico" : "Пуерто-Ріко ",
    "Palestine, State of" : "Палестина",
    "Portugal" : "Португалія",
    "Palau" : "Палау",
    "Paraguay" : "Парагвай",
    "Qatar" : "Катар",
    "Réunion" : "Реюньйон",
    "Romania" : "Румунія",
    "Serbia" : "Сербія",
    "Russian Federation" : "мордор",
    "Rwanda" : "Руанда",
    "Saudi Arabia" : "Саудівська Аравія ",
    "Solomon Islands" : "Соломонові острови ",
    "Seychelles" : "Сейшельські острови ",
    "Sudan" : "Судан",
    "Sweden" : "Швеція",
    "Singapore" : "Сингапур",
    "Saint Helena, Ascension and Tristan da Cunha" : "острова Святої Єлени, Вознесіння та Тристан-да-Кунья ",
    "Slovenia" : "Словенія",
    "Svalbard and Jan Mayen" : "Шпіцберген і Ян-Майєн ",
    "Slovakia" : "Словаччина",
    "Sierra Leone" : "Сьєрра-Леоне ",
    "San Marino" : "Сан-Марино ",
    "Senegal" : "Сенегал",
    "Somalia" : "Сомалі",
    "Suriname" : "Суринам",
    "South Sudan" : "Південний Судан ",
    "Sao Tome and Principe" : "Сан-Томе і Принсіпі ",
    "El Salvador" : "Сальвадор ",
    "Sint Maarten (Dutch part)" : "Сінт-Мартен (нідерландська частина) ",
    "Syrian Arab Republic" : "Сирійська Арабська Республіка ",
    "Eswatini" : "Есватіні",
    "Turks and Caicos Islands" : "Острови Теркс і Кайкос ",
    "Chad" : "Чад",
    "French Southern Territories" : "Французькі Південні й Антарктичні Території",
    "Togo" : "Того",
    "Thailand" : "Таїланд",
    "Tajikistan" : "Таджикистан",
    "Tokelau" : "Токелау",
    "Timor-Leste" : "Тимор-Лешті ",
    "Turkmenistan" : "Туркменістан",
    "Tunisia" : "Туніс",
    "Tonga" : "Тонга",
    "Turkey" : "Туреччина",
    "Trinidad and Tobago" : "Тринідад і Тобаго ",
    "Tuvalu" : "Тувалу",
    "Taiwan, Province of China" : "Тайвань",
    "Tanzania, United Republic of" : "Танзанія",
    "Ukraine" : "Україна",
    "Uganda" : "Уганда",
    "United States Minor Outlying Islands" : "Малі Віддалені Острови Сполучених Штатів Америки ",
    "United States of America" : "Сполучені Штати Америки ",
    "Uruguay" : "Уругвай",
    "Uzbekistan" : "Узбекистан",
    "Holy See" : "Святий Престол ",
    "Saint Vincent and the Grenadines" : "Сент-Вінсент і Гренадини ",
    "Venezuela, Bolivarian Republic of" : "Венесуела, Боліваріанська Республіка",
    "Virgin Islands, British" : "Віргінські острови, Великобританія",
    "Virgin Islands, U.S." : "Віргінські острови, США",
    "Viet Nam" : "В'єтнам ",
    "Vanuatu" : "Вануату",
    "Wallis and Futuna" : "Уолліс і Футуна ",
    "Samoa" : "Самоа",
    "Yemen" : "Ємен",
    "Mayotte" : "Майотта",
    "South Africa" : "Півде́нно-Африка́нська Респу́бліка",
    "Zambia" : "Замбія",
    "Zimbabwe" : "Зімбабве",
    "Background blur" : "Розмиття фону",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Не вдалося перевірити підтримку завантаження WASM. Будь ласка, перевірте вручну, чи обслуговує ваш веб-сервер файли `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Ваш веб-сервер не налаштований належним чином для доставки файлів `.wasm`. Зазвичай це проблема з конфігурацією Nginx. Для розмиття фону потрібно налаштувати доставку файлів `.wasm`. Порівняйте свою конфігурацію Nginx з рекомендованою конфігурацією в нашій документації.",
    "Talk configuration values" : "Значення конфігурації розмови",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Примусове обмеження тривалості виклику підтримується лише за допомогою системного cron. Будь ласка, увімкніть системний cron або видаліть конфігурацію `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Невеликі значення `max_call_duration` (наразі встановлено %d) не можуть бути застосовані через технічні обмеження. Фонове завдання виконується лише кожні 5 хвилин, тому використовуйте його на власний ризик.",
    "Federation" : "Об'єднання",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Наполегливо рекомендується налаштувати \"memcache.locking\", коли увімкнено Talk Federation.",
    "High-performance backend" : "Високопродуктивний бекенд",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Не налаштовано високопродуктивний бекенд - Використання Nextcloud Talk без високопродуктивного бекенду дозволяє лише дуже невеликі дзвінки (максимум 2-3 учасники). Налаштуйте високопродуктивний бекенд, щоб забезпечити безперебійну роботу дзвінків з багатьма учасниками.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Використання високопродуктивного бекенду в режимі «conversation_cluster» є застарілим і більше не буде підтримуватися в наступній версії. Високопродуктивний бекенд зараз підтримує реальне кластеризування, яке слід використовувати замість цього.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Визначення декількох високопродуктивних бекендів є застарілим і більше не буде підтримуватися в наступній версії. Замість цього слід налаштувати балансувальник навантаження разом із кластерними серверами сигналізації та налаштувати його в параметрах Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Збережений відкритий ключ для алгоритму %1$s не збігається зі збереженим закритим ключем. Запустіть %2$s, щоб виправити помилку.",
    "High-performance backend not configured correctly. Run %s for details." : "Високопродуктивний бекенд налаштовано неправильно. Запустіть %s для отримання детальної інформації.",
    "High-performance backend not configured correctly" : "Високопродуктивний бекенд налаштовано неправильно",
    "Error: Cannot connect to server" : "Помилка: Не вдається підключитися до сервера",
    "Error: Server did not respond with proper JSON" : "Помилка: Сервер не відповів правильним JSON",
    "Error: Certificate expired" : "Помилка: Термін дії сертифіката закінчився",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Помилка: Системний час сервера Nextcloud та високопродуктивного сервера бекенду не синхронізований. Переконайтеся, що обидва сервери підключені до сервера часу, або вручну синхронізуйте їх час.",
    "Could not get version" : "Не вдалося отримати версію",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Помилка: Запущена версія: {version}; Сервер потрібно оновити, щоб він був сумісний з цією версією Talk",
    "Error: Server responded with: {error}" : "Помилка: Сервер відповів: {error}",
    "Error: Unknown error occurred" : "Помилка: Сталася невідома помилка",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Попередження: Поточна версія: {version}; Сервер не підтримує всі можливості цієї версії Talk, відсутні функції: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Наполегливо рекомендується налаштувати кеш пам'яті під час запуску Nextcloud Talk з високопродуктивним бекендом.",
    "Client Push" : "Клієнтський поштовх",
    "Recording backend" : "Бекенд для запису",
    "Using the recording backend requires a High-performance backend." : "Використання бекенду для запису вимагає високопродуктивного бекенду.",
    "No recording backend configured" : "Не налаштовано бекенд для запису",
    "SIP configuration" : "Налаштування SIP",
    "Using the SIP functionality requires a High-performance backend." : "Використання функціональності SIP вимагає високопродуктивного бекенда.",
    "No SIP backend configured" : "Не налаштовано бекенд SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Недійсна дата, формат дати має бути РРРР-ММ-ДД",
    "Conversation not found" : "Розмову не знайдено",
    "Path is already shared with this conversation" : "Шлях вже пройдений з цією розмовою",
    "Chat, video & audio-conferencing using WebRTC" : "Чат, відео- та аудіоконференції за допомогою WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Чат, відео- та аудіоконференції за допомогою WebRTC\n\n* 💬 **Чат** Nextcloud Talk має простий текстовий чат, що дозволяє ділитися або завантажувати файли з програми Nextcloud Files або локального пристрою та згадувати інших учасників.\n* 👥 **Приватні, групові, публічні та захищені паролем дзвінки!** Запросіть когось, цілу групу або надішліть публічне посилання, щоб запросити на дзвінок.\n* 🌐 **Федеративні чати** Чатуйте з іншими користувачами Nextcloud на їхніх серверах\n* 💻 **Спільний доступ до екрана!** Діліться своїм екраном з учасниками дзвінка.\n* 🚀 **Інтеграція з іншими додатками Nextcloud**, такими як Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck та багатьма іншими.\n* 🌉 **Синхронізація з іншими чат-рішеннями** Завдяки інтеграції [Matterbridge](https://github.com/42wim/matterbridge/) у Talk ви можете легко синхронізувати багато інших чат-рішень із Nextcloud Talk і навпаки.",
    "Leave call" : "Вийти",
    "Navigating away from the page will leave the call in {conversation}" : "При переході зі сторінки виклик залишиться у {conversation}",
    "Stay in call" : "Залишатися",
    "Error occurred when getting the conversation information" : "Виникла помилка при отриманні інформації про розмову",
    "Duplicate session" : "Дублікат сеансу",
    "Discuss this file" : "Обговорити цей файл",
    "Loading …" : "Завантаження …",
    "Share this file with others to discuss it" : "Поділітися цим файлом з іншими, щоб обговорити його",
    "Join conversation" : "Приєднатися",
    "Share this file" : "Поділитися файлом",
    "Error occurred when joining the conversation" : "Виникла помилка під час приєднання до розмови",
    "This conversation is password-protected." : "Ця розмова захищена паролем.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Ми виявили кілька невірних спроб введення пароля з вашого IP. Тому ваша наступна спроба буде обмежена до 30 секунд.",
    "The password is wrong. Try again." : "Пароль неправильний. Спробуйте ще раз.",
    "Password" : "Пароль",
    "Submit" : "Гаразд",
    "Error requesting the password." : "Помилка при запиті пароля.",
    "Request password" : "Запит пароля",
    "This conversation has ended" : "Ця розмова завершилася",
    "Close Talk sidebar" : "Закрити бічну панель",
    "Open Talk sidebar" : "Відкрити бічну панель",
    "Everyone" : "Всі",
    "Users and moderators" : "Учасники та модератори",
    "Moderators only" : "Тільки модератори",
    "Disable calls" : "Вимкнути дзвінки",
    "Save changes" : "Зберегти зміни",
    "Saving …" : "Збереження …",
    "Saved!" : "Збережено!",
    "Limit to groups" : "Обмежити групами",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Якщо вибрано хоча б одну групу, в розмовах можуть брати участь лише користувачі із зазначених груп.",
    "Guests can still join public conversations." : "Гості все ще можуть приєднуватися до публічних розмов.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Користувачі, які більше не можуть користуватися чатом, залишаться в списку учасників попередніх розмов, а їхні повідомлення в чаті будуть збережені.",
    "Limit using Talk" : "Обмеження на використання Talk",
    "Limit creating a public and group conversation" : "Обмежте створення публічних та групових розмов",
    "Limit creating conversations" : "Обмеження на створення розмов",
    "Limit starting a call" : "Обмеження на початок дзвінка",
    "Limit starting calls" : "Обмежити створення викликів",
    "When a call has started, everyone with access to the conversation can join the call." : "Після початку виклику будь-хто, хто має доступ до розмови, може приєднатися до конференції.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "На цьому сервері встановлені наступні боти. У документації ви можете знайти детальну інформацію про те, як {linkstart1}створити власного бота{linkend} або {linkstart2}список ботів{linkend}, які можна ввімкнути на вашому сервері.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "На цьому сервері не встановлено ботів. У документації ви можете знайти детальну інформацію про те, як {linkstart1}створити власного бота{linkend} або {linkstart2}список ботів{linkend}, які можна ввімкнути на вашому сервері.",
    "Description is not provided" : "Опис не надається",
    "Locked for moderators" : "Заблоковано для модераторів",
    "Enabled" : "Увімкнено",
    "Disabled" : "Вимкнено",
    "Bots settings" : "Налаштування ботів",
    "State" : "Стан",
    "Name" : "Ім'я",
    "Last error" : "Остання помилка",
    "Total errors count" : "Загальна кількість помилок",
    "Find more bots" : "Знайти більше ботів",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Довірені сервери можна налаштувати на сторінці {linkstart}Налаштування спільного доступу{linkend}.",
    "Beta" : "Бета",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Об'єднані чати та дзвінки вже працюють. Робота з вкладеннями буде реалізована в наступній версії.",
    "Enable Federation in Talk app" : "Увімкнути застосунок об'єднані хмари для Talk",
    "Permissions" : "Дозволи ",
    "Allow users to be invited to federated conversations" : "Дозволити користувачам запрошувати вас до розмов з інших хмар",
    "Allow users to invite federated users into conversation" : "Дозвольте користувачам запрошувати користувачів з інших хмар до бесіди",
    "Only allow to federate with trusted servers" : "Дозволяти об'єднуватися лише з довіреними серверами",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Якщо вибрано хоча б одну групу, тільки люди з перелічених груп можуть запрошувати об'єднаних користувачів до розмов.",
    "Groups allowed to invite federated users" : "Групи, яким дозволено запрошувати об'єднаних користувачів",
    "Select groups …" : "Виберіть групи ...",
    "All messages" : "Всі повідомлення",
    "@-mentions only" : "Тільки @-згадки",
    "Off" : "Вимкнути",
    "General settings" : "Загальні",
    "Default notification settings" : "Налаштування сповіщень за замовчуванням",
    "Default group notification" : "Сповіщення групи за замовчуванням",
    "Default group notification for new groups" : "Сповіщення для нових груп за замовчуванням",
    "Integration into other apps" : "Інтеграція з іншими додатками",
    "Allow conversations on files" : "Дозволити обговорення файлів",
    "Allow conversations on public shares for files" : "Дозволити розмови на спільних ресурсах для файлів",
    "End-to-end encrypted calls" : "Наскрізні зашифровані дзвінки",
    "Enable encryption" : "Увімкнути шифрування",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Наскрізні зашифровані дзвінки з налаштованим SIP-мостом потребують новішої версії Високопродуктивного бекенду та SIP-мосту.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Наразі мобільні клієнти не підтримують наскрізні зашифровані дзвінки.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "При натисканні на кнопку вище інформація з форми буде відправлена на сервери компанії Struktur AG. Ви можете знайти додаткову інформацію на {linkstart}spreed.eu{linkend}.",
    "Pending" : "Очікування",
    "Error" : "Помилка",
    "Blocked" : "Заблоковано",
    "Active" : "Активно",
    "Expired" : "Закінчився",
    "Never" : "Ніколи",
    "The trial could not be requested. Please try again later." : "Не вдалося запросити пробний період використання. Повторіть спробу через деякий час.",
    "The account could not be deleted. Please try again later." : "Обліковий запис не вдалося вилучити. Будь ласка, спробуйте пізніше.",
    "Hosted High-performance backend" : "Високопродуктивний бекенд на хостингу",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Наш партнер Struktur AG надає послугу, за допомогою якої можна замовити розміщення сервера сигналізації. Для цього вам потрібно лише заповнити форму нижче, і ваш Nextcloud надішле запит. Щойно сервер буде налаштовано для вас, облікові дані будуть заповнені автоматично. При цьому будуть перезаписані існуючі налаштування сервера сигналізації.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Якщо ваш високопродуктивний бекенд-акаунт включає функції STUN і/або TURN, налаштування будуть оновлені відповідно.",
    "URL of this Nextcloud instance" : "Посилання на цей сервер хмари Nextcloud",
    "Full name of the user requesting the trial" : "Повне ім'я користувача, який запитує пробну версію",
    "Email of the user" : "Електронна адреса користувача",
    "Language" : "Мова",
    "Country" : "Країна",
    "Request signaling server trial" : "Запит на пробну версію сервера сигналізації",
    "You can see the current status of your hosted signaling server in the following table." : "Ви можете побачити поточний стан вашого сервера сигналізації в наступній таблиці.",
    "Status" : "Статус",
    "Created at" : "Створено",
    "Expires at" : "Термін дії закінчується",
    "Limits" : "Обмеження",
    "STUN included" : "STUN включено",
    "Yes" : "Так",
    "No" : "Ні",
    "TURN included" : "ТУР включено",
    "Delete the signaling server account" : "Вилучити обліковий запис сервера сигналізації",
    "_%n user_::_%n users_" : ["%n користувач","%n користувача","%n користувачів","%n користувачів"],
    "Installed version: {version}" : "Встановлена версія: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Ви можете встановити застосунок Matterbridge, щоб зв'язати Nextcloud Talk з деякими іншими сервісами, відвідайте їхню {linkstart1}GitHub-сторінку{linkend} для отримання додаткової інформації. Завантаження та встановлення застосунку може зайняти деякий час. Якщо час очікування минув, встановіть його вручну з {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Бінарний файл Matterbridge має неправильні дозволи. Переконайтеся, що бінарний файл Matterbridge належить правильному користувачеві і може бути виконаний. Його можна знайти в «/…/nextcloud/apps/talk_matterbridge/bin/».",
    "Matterbridge binary was not found or couldn't be executed." : "Бінарний файл Matterbridge не знайдено або не вдалося виконати.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Ви також можете вказати шлях до бінарного файлу Matterbridge в конфігураційному файлі. Для отримання додаткової інформації зверніться до {linkstart}документації з інтеграції Matterbridge{linkend}.",
    "Downloading …" : "Отримання ...",
    "Install Talk Matterbridge" : "Встановіть Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Виникла помилка під час встановлення застосунку Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Під час інсталяції Talk Matterbridge сталася помилка. Будь ласка, встановіть його вручну",
    "Failed to execute Matterbridge binary." : "Не вдалося виконати бінарний файл Matterbridge.",
    "Matterbridge integration" : "Інтеграція Matterbridge",
    "Enable Matterbridge integration" : "Enable Matterbridge integration",
    "Status: Checking connection" : "Статус: Перевірка з'єднання",
    "OK: Running version: {version}" : "ОК: Запущена версія: {version}",
    "Error: Server seems to be a Signaling server" : "Помилка: Здається, що сервер є сервером сигналізації",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Помилка: Системний час сервера Nextcloud та сервера запису не синхронізований. Переконайтеся, що обидва сервери підключені до сервера часу, або вручну синхронізуйте їх час.",
    "Recording backend URL" : "Запис URL-адреси бекенду",
    "Validate SSL certificate" : "Перевірити сертифікат SSL",
    "Delete this server" : "Вилучити цей сервер",
    "Test this server" : "Перевірте цей сервер",
    "Disabled for all calls" : "Вимкнено для всіх дзвінків",
    "Enabled for all calls" : "Ввімкнено для всіх дзвінків",
    "Configurable on conversation level by moderators" : "Налаштовується на рівні розмови модераторами",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Налаштування PHP \"upload_max_filesize\" або \"post_max_size\" дозволять завантажувати файли розміром лише до {maxUpload}.",
    "Recording backend settings saved" : "Збережено запис налаштувань бекенду",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Модератори матимуть право увімкнути згоду на рівні розмови. Згода на запис буде вимагатися від кожного учасника перед тим, як приєднатися до кожного дзвінка в цій розмові.",
    "The consent to be recorded will be required for each participant before joining every call." : "Згода на запис буде вимагатися від кожного учасника перед тим, як приєднатися до кожного дзвінка.",
    "The consent to be recorded is not required." : "Згода на запис не потрібна.",
    "Recording backend configuration is only possible with a High-performance backend." : "Запис конфігурації бекенда можливий лише з Високопродуктивним бекендом.",
    "Add a new recording backend server" : "Додати новий сервер бекенд-запису",
    "Shared secret" : "Спільний секрет",
    "Recording consent" : "Згода на запис",
    "Recording transcription" : "Транскрипція запису",
    "Automatically transcribe call recordings with a transcription provider" : "Автоматично розшифровуйте записи дзвінків за допомогою постачальника транскрипції",
    "Automatically summarize call recordings with transcription and summary providers" : "Автоматично підсумовуйте записи дзвінків за допомогою постачальників транскрипції та резюме",
    "SIP configuration saved!" : "Налаштування SIP збережено!",
    "SIP configuration is only possible with a High-performance backend." : "Конфігурація SIP можлива тільки з високопродуктивним бекендом.",
    "Enable SIP Dial-out option" : "Увімкніть опцію SIP Dial-out",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Сервер сигналізації необхідно оновити, щоб він підтримував функцію SIP Dial-out.",
    "Do not show SIP Dial-out caller number" : "Не показувати номер абонента, що дзвонить через SIP",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Анонімний номер повинен відображатися як «невідомий» або «прихований номер» для абонента, якому дзвонять.",
    "Dial-out number" : "Номер для виклику",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Номер у форматі E164, який використовується як резервний номер абонента для вихідних дзвінків",
    "Dial-out prefix" : "Префікс вихідного дзвінка",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Префікс до налаштованого номера користувача для вихідних дзвінків (за замовчуванням `+`)",
    "Restrict SIP configuration" : "Обмеження конфігурації SIP",
    "Enable SIP configuration" : "Увімкнути налаштування SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Тільки користувачі наступних груп можуть увімкнути SIP у розмовах, які вони модерують",
    "Phone number (Country)" : "Номер телефону (Країна)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Ця інформація надсилається в електронних листах-запрошеннях, а також відображається на бічній панелі для всіх учасників.",
    "Nextcloud base URL" : "URL-адреса бази Nextcloud",
    "Talk Backend URL" : "URL-адреса бекенда для розмови",
    "WebSocket URL" : "URL-адреса веб-сокета",
    "Available features" : "Доступні функції",
    "Error: Websocket connection failed" : "Помилка: Не вдалося з'єднатися з веб-сокетом",
    "Error code" : "Код помилки",
    "Error message" : "Повідомлення про помилку",
    "Error: Websocket connection failed. Check browser console" : "Помилка: Не вдалося з'єднатися з веб-сокетом. Перевірте консоль браузера",
    "High-performance backend URL" : "URL-адреса високопродуктивного бекенда",
    "Missing High-performance backend warning hidden" : "Відсутнє Високопродуктивний бекенд-попередження приховано",
    "High-performance backend settings saved" : "Збережено високопродуктивні налаштування бекенда",
    "Nextcloud Talk setup not complete" : "NextНалаштування хмарної розмови не завершено",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Зверніть увагу, що під час дзвінків із більш ніж 2 учасниками без високопродуктивного бекенду учасники, швидше за все, зіткнуться з проблемами підключення та спричинять високе навантаження на пристрої учасників.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Встановіть високопродуктивний бекенд, щоб забезпечити безперебійну роботу дзвінків з кількома учасниками.",
    "Nextcloud portal" : "Портал Nextcloud",
    "Quick installation guide" : "Короткий посібник з монтажу",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Високопродуктивний бекенд необхідний для дзвінків і розмов з декількома учасниками. Без бекенду всі учасники повинні завантажувати своє відео індивідуально для кожного іншого учасника, що, швидше за все, спричинить проблеми з підключенням і високе навантаження на пристрої учасників.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Наполегливо рекомендується налаштувати розподілений кеш, якщо ви використовуєте Nextcloud Talk з високопродуктивним бекендом.",
    "Add High-performance backend server" : "Додати Високопродуктивний сервер бекенда",
    "Warn about connectivity issues in calls with more than 2 participants" : "Попередження про проблеми зі з'єднанням під час дзвінків з більш ніж 2 учасниками",
    "STUN server URL" : "URL-адреса сервера STUN",
    "The server address is invalid" : "Адреса сервера є недійсною",
    "STUN settings saved" : "Налаштування STUN збережено",
    "STUN servers" : "Сервер STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN-сервер використовується для визначення публічної IP-адреси учасників за маршрутизатором.",
    "Add a new STUN server" : "Додати новий сервер STUN",
    "{schema} scheme must be used with a domain" : "{schema} схема повинна використовуватися з доменом",
    "{option1} and {option2}" : "{option1} і {option2}",
    "{option} only" : "{option} тільки",
    "OK: Successful ICE candidates returned by the TURN server" : "ГАРАЗД: Успішні кандидати ICE повернуті сервером TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Помилка: Сервер TURN не повернув жодного робочого кандидата ICE",
    "Testing whether the TURN server returns ICE candidates" : "Тестування, чи повертає сервер TURN кандидатів на ICE",
    "TURN server schemes" : "Схеми серверів TURN",
    "TURN server URL" : "URL-адреса сервера TURN",
    "TURN server secret" : "Секрет сервера TURN",
    "TURN server protocols" : "Протоколи сервера TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Сервер TURN використовується для проксі-передачі трафіку від учасників, які знаходяться за брандмауером. Якщо окремі учасники не можуть підключитися до інших, найімовірніше, необхідний сервер TURN. Інструкції з налаштування див. у {linkstart} цій документації{linkend}.",
    "TURN settings saved" : "Налаштування TURN збережено",
    "TURN servers" : "Сервери TURN",
    "Add a new TURN server" : "Додати новий сервер TURN",
    "Failed" : "Не вдалося",
    "OK" : "Гаразд",
    "Checking …" : "Перевірка...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Не вдалося: WebAssembly вимкнено або не підтримується в цьому браузері. Увімкніть WebAssembly або скористайтеся браузером, який його підтримує, щоб виконати перевірку.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Не вдалося: Файли \".wasm\" і \".tflite\" некоректно повернуто веб-сервером. Будь ласка, перевірте розділ \"Системні вимоги\" в документації Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: файли \".wasm\" і \".tflite\" коректно повернуто веб-сервером.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Схоже, що конфігурація PHP та Apache несумісні. Зверніть увагу, що PHP можна використовувати лише з модулем MPM_PREFORK, а PHP-FPM — лише з модулем MPM_EVENT.",
    "Web server setup checks" : "Перевірка налаштувань веб-сервера",
    "Files required for virtual background can be loaded" : "Файли, необхідні для віртуального фону, можна завантажити",
    "Federated user" : "Обʼєднаний користувач",
    "Assign participants to rooms" : "Розподіліть учасників по кімнатах",
    "Configure breakout rooms" : "Налаштування секційних кімнат",
    "Number of breakout rooms" : "Кількість секційних кімнат",
    "You can create from 1 to 20 breakout rooms." : "Ви можете створити від 1 до 20 секційних кімнат.",
    "Assignment method" : "Метод призначення",
    "Automatically assign participants" : "Автоматичне призначення учасників",
    "Manually assign participants" : "Призначайте учасників вручну",
    "Allow participants to choose" : "Дозволити учасникам обирати",
    "Create rooms" : "Створити кімнати",
    "Confirm" : "Підтвердити",
    "Create breakout rooms" : "Створіть кімнати для переговорів",
    "Reset" : "Скидання",
    "Delete breakout rooms" : "Видалити окремі кімнати",
    "Room {roomNumber}" : "Кімната {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Поточні кімнати та налаштування будуть втрачені",
    "Cancel" : "Скасувати",
    "Unassigned participants" : "Непризначені учасники",
    "Back" : "Назад",
    "Assign" : "Призначити",
    "Add participant \"{user}\"" : "Додати учасника \"{user}\"",
    "Now" : "Зараз",
    "Invalid calendar selected" : "Вибрано невірний календар",
    "Invalid start time selected" : "Вибрано невірний час запуску",
    "Invalid end time selected" : "Вибрано невірний час закінчення",
    "Unknown error occurred" : "Виникла невідома помилка",
    "Sending no invitations" : "Не надсилати запрошення",
    "{participant0} will receive an invitation" : "{participant0} отримають запрошення",
    "{participant0} and {participant1} will receive invitations" : "{participant0} та {participant1} отримають запрошення",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} та %n інших отримають запрошення","{participant0}, {participant1} та %n інших отримають запрошення","{participant0}, {participant1} та %n інших отримають запрошення","{participant0}, {participant1} та %n інших отримають запрошення"],
    "Invite {user}" : "Запросити {user}",
    "Invite all users and emails in this conversation" : "Запросіть усіх користувачів та адреси електронної пошти до цієї розмови",
    "Meeting created" : "Зустріч створено",
    "Upcoming meetings" : "Найближчі зустрічі",
    "No upcoming meetings" : "Немає найближчих зустрічей",
    "Schedule a meeting" : "Заплануйте зустріч",
    "Meeting title" : "Назва зустрічі",
    "From" : "Від",
    "To" : "Кому",
    "Calendar" : "Календар",
    "Attendees" : "Учасники",
    "No other participants to send invitations to." : "Інших учасників, яким потрібно надсилати запрошення, немає.",
    "Add attendees" : "Додати учасників",
    "Save" : "Зберегти",
    "Search participants" : "Пошук учасників",
    "No results" : "Немає результатів",
    "Done" : "Готово",
    "Disable live transcription" : "Вимкнути транскрипцію в прямому ефірі",
    "Exit full screen (F)" : "Вийти з повноекранного режиму (F)",
    "Full screen (F)" : "На весь екран (F)",
    "Speaker view" : "Вигляд динаміка",
    "Grid view" : "Упорядкування у формі сітки",
    "Error when trying to load the available live transcription languages" : "Помилка при спробі завантажити доступні мови транскрипції в реальному часі",
    "Failed to enable live transcription" : "Не вдалося увімкнути транскрипцію в реальному часі",
    "Recording consent is required" : "Згода на запис необхідна",
    "This conversation is read-only" : "Ця розмова призначена лише для читання",
    "Conversation not found or not joined" : "Розмова не знайдена або не приєднана",
    "Lobby is still active and you're not a moderator" : "Лобі все ще активне, а ви не є модератором",
    "Connection failed" : "Не вдалося встановити з'єднання",
    "Reload" : "Перезавантажити",
    "{nickName} raised their hand." : "{nickName} підняв руку.",
    "A participant raised their hand." : "Один з учасників підняв руку.",
    "Collapse stripe" : "Смуга згортання",
    "Expand stripe" : "Розгорнути смугу",
    "Previous page of videos" : "Попередня сторінка відео",
    "Next page of videos" : "Наступна сторінка відео",
    "Connecting …" : "Підключення ...",
    "Calling …" : "Викликаю...",
    "Waiting for {user} to join the call" : "Чекаємо на {user}, щоб долучитися до конкурсу",
    "Waiting for others to join the call …" : "Чекаємо, доки хтось приєднається до виклику...",
    "You can invite others in the participant tab of the sidebar" : "Ви можете запросити користувачів у вкладці учасники на бічній панелі",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Ви можете запросити користувачів у вкладці учасники на бічній панелі або поділитися цим посиланням, щоб запросити інших!",
    "Share this link to invite others!" : "Поділіться цим посиланням з тими, кого бажаєте запросити!",
    "Copy link" : "Копіювати посилання",
    "You are not allowed to enable audio" : "Ви не маєте права вмикати аудіо",
    "No audio. Click to select device" : "Немає звуку. Натисніть, щоб вибрати пристрій",
    "Mute audio" : "Вимкнути мікрофон (m)",
    "Mute audio (M)" : "Вимкнути звук (M)",
    "Unmute audio" : "Увімкнути мікрофон",
    "Unmute audio (M)" : "Увімкнути звук (M)",
    "None" : "Відсутній",
    "Select a microphone" : "Виберіть мікрофон",
    "Select a speaker" : "Виберіть динамік",
    "Check devices" : "Перевірте пристрої",
    "Access to camera was denied" : "Доступ до камери було заборонено",
    "Error while accessing camera: It is likely in use by another program" : "Помилка під час доступу до камери: Ймовірно, вона використовується іншою програмою",
    "Error while accessing camera" : "Помилка під час доступу до камери",
    "You have been muted by a moderator" : "Ви були приглушені модератором",
    "Hide presenter video" : "Приховати відео ведучого",
    "You are not allowed to enable video" : "Ви не маєте права вмикати відео",
    "No video. Click to select device" : "Немає відео. Натисніть, щоб вибрати пристрій",
    "Disable video" : "Вимкнути відео",
    "Disable video (V)" : "Вимкнути відео (V)",
    "Enable video" : "Увімкнути відео",
    "Enable video (V)" : "Увімкнути відео (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Увімкнути відео - Під час першого ввімкнення відео з'єднання буде ненадовго перервано",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Увімкнути відео (V) - Під час першого ввімкнення відео з'єднання буде ненадовго перервано",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Увімкнути відео. Під час першого ввімкнення відео з'єднання буде ненадовго перервано",
    "Select a video device" : "Виберіть відеопристрій",
    "Show presenter" : "Ведучий шоу",
    "You" : "Ви",
    "Mute" : "Вимкнути звук",
    "Muted" : "Без звуку.",
    "Show screen" : "Демонстрація екрану",
    "Stop following" : "Припиніть стежити",
    "Connection could not be established …" : "Не вдалося встановити з'єднання ...",
    "Connection was lost and could not be re-established …" : "З'єднання було втрачено і не вдалося відновити ...",
    "Connection could not be established. Trying again …" : "Не вдалося встановити з'єднання. Повторна спроба ...",
    "Connection lost. Trying to reconnect …" : "З'єднання втрачено. Спроба повторного підключення ...",
    "Connection problems …" : "Проблеми з підключенням ...",
    "Collapse" : "Згорнути",
    "Expand" : "Розгорнути",
    "You need to be logged in to upload files" : "Для завантаження файлів потрібно авторизуватися",
    "Drop your files to upload" : "Перетягнути файли для завантаження",
    "Conversation messages" : "Розмовні повідомлення",
    "Scroll to bottom" : "Прокрутіть донизу",
    "Post message" : "Опублікувати повідомлення",
    "Federated conversation" : "Федеративна розмова",
    "Public conversation" : "Публічна розмова",
    "Favorite" : "Із зірочкою",
    "Banned users" : "Заборонені користувачі",
    "Manage the list of banned users in this conversation." : "Керуйте списком заблокованих користувачів у цій розмові.",
    "Manage bans" : "Керування заборонами",
    "No banned users" : "Немає заборонених користувачів",
    "Banned by:" : "Заборонено:",
    "Date:" : "Дата:",
    "Note:" : "Примітка:",
    "Hide details" : "Приховати деталі",
    "Show details" : "Показати деталі",
    "Unban" : "Розбан",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Ви можете змінити назву та опис в {linkstart}Календар{linkend}.",
    "Error while updating conversation name" : "Помилка під час оновлення назви розмови",
    "Error while updating conversation description" : "Помилка під час оновлення опису розмови",
    "Enter a name for this conversation" : "Введіть назву для цієї розмови",
    "Edit conversation name" : "Редагувати назву розмови",
    "Edit conversation description" : "Редагувати опис розмови",
    "Enter a description for this conversation" : "Введіть опис для цієї розмови",
    "Picture" : "Зображення",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "У цій розмові можна увімкнути наступні боти. Зверніться до адміністрації, щоб встановити на цьому сервері більше ботів.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "На цьому сервері не встановлено ботів. Зверніться до своєї адміністрації, щоб встановити ботів на цьому сервері.",
    "Disable" : "Вимкнути",
    "Enable" : "Увімкнути",
    "Breakout rooms" : "Кімнати обговорення",
    "Manage breakout rooms" : "Керуйте секційними кімнатами",
    "Set up breakout rooms for this conversation" : "Організуйте окремі кімнати для цієї розмови",
    "Please select a valid PNG or JPG file" : "Будь ласка, виберіть правильний файл у форматі PNG або JPG",
    "Choose your conversation picture" : "Виберіть картинку для розмови",
    "Choose" : "Вибрати",
    "Error setting conversation picture" : "Помилка встановлення картинки розмови",
    "Could not set the conversation picture: {error}" : "Не вдалося встановити картинку розмови: {error}",
    "Error cropping conversation picture" : "Помилка обрізання картинки розмови",
    "Error removing conversation picture" : "Помилка видалення зображення розмови",
    "Set emoji as conversation picture" : "Встановіть емодзі як картинку для розмови",
    "Set background color for conversation picture" : "Задати колір фону для зображення розмови",
    "Upload conversation picture" : "Завантажити фотографію розмови",
    "Choose conversation picture from files" : "Виберіть картинку для розмови з файлів",
    "Remove conversation picture" : "Видалити фотографію розмови",
    "The file must be a PNG or JPG" : "Файл у форматі PNG або JPG",
    "Set picture" : "Встановлене зображення",
    "Default permissions modified for {conversationName}" : "Дозволи за замовчуванням змінено для {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Не вдалося змінити дозволи за замовчуванням для {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Відредагуйте дозволи за замовчуванням для учасників цієї бесіди. Ці налаштування не впливають на модераторів.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "При кожній зміні дозволів у цьому розділі дозволи користувачів, які було призначено окремим учасникам, будуть втрачені.",
    "All permissions" : "Усі дозволи",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Учасники мають дозволи на початок дзвінка, приєднання до дзвінка, увімкнення аудіо та відео, а також спільний доступ до екрана.",
    "Restricted" : "Обмежена",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Учасники можуть приєднуватися до дзвінків, але не можуть увімкнути аудіо, відео або надати спільний доступ до екрану, поки модератор вручну не надасть їм відповідні дозволи.",
    "Advanced permissions" : "Розширені дозволи",
    "Edit permissions" : "Редагування дозволів",
    "Conversation settings" : "Налаштування розмови",
    "Basic Info" : "Основна інформація",
    "Personal" : "Особисте",
    "Moderation" : "Модерація",
    "Setup overview" : "Огляд налаштувань",
    "Live transcription" : "Транскрипція наживо",
    "Enable live transcription" : "Ввімкнути транскрипцію в прямому ефірі",
    "Breakout Rooms" : "Секційні кімнати",
    "Matterbridge" : "Маттербрідж",
    "Bots" : "Боти",
    "Danger zone" : "Небезпечна зона",
    "Archive conversation" : "Архівна розмова",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Архівні розмови за замовчуванням приховані зі списку розмов. Однак вони все одно будуть відображатися, коли ви шукаєте назву розмови або переходите до списку архівних розмов.",
    "Do you really want to leave \"{displayName}\"?" : "Ви дійсно хочете покинути \"{displayName}\"?",
    "You can archive this conversation instead." : "Замість цього ви можете заархівувати цю розмову.",
    "Leave conversation" : "Залишити спілкування",
    "You need to promote a new moderator before you can leave the conversation" : "Перед тим, як вийти з розмови, вам потрібно призначити нового модератора",
    "Delete conversation" : "Вилучити розмову",
    "Do you really want to delete \"{displayName}\"?" : "Дійсно вилучити \"{displayName}\"?",
    "Error while deleting conversation" : "Помилка при видаленні розмови",
    "Delete all chat messages" : "Вилучити всі повідомлення чату",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Ви дійсно хочете видалити всі повідомлення в \"{displayName}\"?",
    "Error while clearing chat history" : "Помилка під час очищення історії чату",
    "Be careful, these actions cannot be undone." : "Будьте обережні, ці дії не можна скасувати.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Якщо ви вийшли з бесіди, щоб знову приєднатися до закритої бесіди, потрібно буде отримати запрошення. До відкритої бесіди можна приєднатися в будь-який час.",
    "Permanently delete this conversation." : "Назавжди вилучити цю розмову.",
    "Delete chat messages" : "Вилучити повідомлення чату",
    "Permanently delete all the messages in this conversation." : "Назавжди вилучити всі повідомлення в цій розмові.",
    "Custom expiration time" : "Індивідуальний термін придатності",
    "Message expiration disabled" : "Вимкнено закінчення терміну дії повідомлення",
    "Message expiration set: {duration}" : "Встановлено термін дії повідомлення: {duration}",
    "Error when trying to set message expiration" : "Помилка при спробі встановити термін дії повідомлення",
    "Message expiration" : "Термін дії повідомлення",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Повідомлення чату можна буде вилучити через певний час. Зверніть увагу, файли, які було надіслано в чаті, не будуть вилучені для автора, але більше не будуть доступні в розмові.",
    "Set message expiration" : "Встановити термін дії повідомлення",
    "Current message expiration" : "Термін дії поточного повідомлення закінчився",
    "Password copied to clipboard" : "Пароль скопійовано до буфера обміну",
    "Password could not be copied" : "Не вдалося скопіювати пароль",
    "Guest access" : "Гостьовий доступ",
    "Breakout rooms are not allowed in public conversations." : "Під час публічних розмов заборонено користуватися кімнатами для переговорів.",
    "Allow guests to join this conversation via link" : "Дозволити гостям приєднатися до цієї розмови за посиланням",
    "Password protection" : "Захист паролем",
    "This conversation is password-protected. Guests need password to join" : "Ця розмова захищена паролем. Гостям потрібен пароль, щоб приєднатися",
    "Password protection is needed for public conversations" : "Захист паролем потрібний для публічних розмов",
    "Set a password" : "Встановити пароль",
    "Change password" : "Змінити пароль",
    "Enter new password" : "Введіть новий пароль",
    "Save password" : "Зберегти пароль",
    "Copy password" : "Скопіювати пароль",
    "Guests are allowed to join this conversation via link" : "Гості можуть долучитися до дискусії за посиланням",
    "Guests are not allowed to join this conversation" : "Гостям не дозволяється приєднуватися до цієї розмови",
    "Resend invitations" : "Повторно надіслати запрошення",
    "This conversation is open to both registered users and users created with the Guests app" : "Ця розмова відкрита як для зареєстрованих користувачів, так і для користувачів, створених за допомогою програми \"Гості",
    "This conversation is open to registered users" : "Ця розмова відкрита для зареєстрованих користувачів",
    "This conversation is limited to the current participants" : "Ця розмова обмежена поточними учасниками",
    "You opened the conversation to both registered users and users created with the Guests app" : "Ви відкрили бесіду як для зареєстрованих користувачів, так і для користувачів, створених за допомогою програми \"Гості",
    "Error occurred when opening or limiting the conversation" : "Виникла помилка при відкритті або обмеженні розмови",
    "Open conversation to registered users, showing it in search results" : "Відкрити бесіду для зареєстрованих користувачів, показуючи її в результатах пошуку",
    "Also open to users created with the Guests app" : "Також відкрито для користувачів, створених у додатку \"Гості",
    "Open conversation" : "Відкрита розмова",
    "Set language spoken in calls" : "Налаштування мови дзвінків",
    "Languages could not be loaded" : "Не вдалося завантажити мови",
    "Loading languages …" : "Завантаження мов ...",
    "Invalid language" : "Недійсний вибір мови",
    "Default language (English)" : "Мова за замовчуванням (англійська)",
    "Default live transcription language set" : "За замовчуванням встановлено мову транскрипції в прямому ефірі",
    "Live transcription language set: {languageName}" : "Набір мов транскрипції в реальному часі: {languageName}",
    "Error when trying to set live transcription language" : "Помилка при спробі встановити мову транскрипції в реальному часі",
    "Start time: {date}" : "Початок: {date}",
    "Start time has been updated" : "Час початку оновлено",
    "Error occurred while updating start time" : "Виникла помилка під час оновлення часу запуску",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Увімкнення лобі вилучить з поточної розмови немодераторів.",
    "Enable lobby, restricting the conversation to moderators" : "Увімкнути лобі, обмеживши розмову модераторами",
    "Meeting start time" : "Час початку зустрічі",
    "Start time (optional)" : "Час початку (за бажанням)",
    "Import email participants" : "Імпортувати імейли учасників",
    "You can import a list of email participants from a CSV file." : "Ви можете імпортувати список учасників розсилки з файлу CSV.",
    "Poll drafts" : "Чернетки опитувань",
    "Browse poll drafts" : "Переглянути чернетки опитувань",
    "Error occurred when locking the conversation" : "Виникла помилка при блокуванні розмови",
    "Error occurred when unlocking the conversation" : "Виникла помилка при розблокуванні розмови",
    "Lock conversation" : "Заблокувати розмову",
    "This will also terminate the ongoing call." : "Це також призведе до завершення поточного виклику.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Блокування розмови, щоб заборонити будь-кому публікувати повідомлення або починати розмову",
    "Edit" : "Редагувати",
    "More information" : "Докладно",
    "Delete" : "Вилучити",
    "Add new bridged channel to current conversation" : "Додати новий мостовий канал до поточної розмови",
    "unknown state" : "невідомий стан",
    "running" : "біг",
    "not running, check Matterbridge log" : "не працює, перевірте журнал Matterbridge",
    "not running" : "не бігаю.",
    "Bridge saved" : "Міст збережено.",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "За допомогою Matterbridge ви можете об'єднати канали з різних систем обміну повідомленнями.",
    "More info on Matterbridge" : "Більше інформації про Matterbridge",
    "Messaging systems" : "Системи обміну повідомленнями",
    "Enable bridge" : "Увімкнути міст",
    "Show Matterbridge log" : "Показати журнал Matterbridge",
    "Log content" : "Вміст журналу",
    "Only moderators are allowed to mention @all" : "Тільки модератори можуть згадувати @all",
    "All participants are allowed to mention @all" : "Всім учасникам дозволяється згадувати @all",
    "Participants are now allowed to mention @all." : "Учасникам тепер дозволено згадувати @all.",
    "Mentioning @all has been limited to moderators." : "Згадування @all дозволено лише модераторам.",
    "Allow participants to mention @all" : "Дозволити учасникам згадувати @all",
    "Mention permissions" : "Дозволи",
    "Notifications" : "Сповіщення",
    "Notify about calls in this conversation" : "Сповіщати про дзвінки в цій розмові",
    "Important conversation" : "Важлива розмова",
    "\"Do not disturb\" user status is ignored for important conversations" : "Статус користувача \"Не турбувати\" ігнорується для важливих розмов",
    "Sensitive conversation" : "Делікатна розмова",
    "Message preview will be disabled in conversation list and notifications" : "Попередній перегляд повідомлень буде вимкнено у списку розмов та сповіщеннях",
    "Recording consent is required for calls in this conversation" : "Згода на запис необхідна для дзвінків у цій розмові",
    "Recording consent is not required for calls in this conversation" : "Згода на запис не потрібна для дзвінків у цій розмові",
    "Recording consent requirement was updated" : "Оновлено вимогу щодо згоди на запис",
    "Error occurred while updating recording consent" : "Виникла помилка під час оновлення згоди на запис",
    "Recording Consent" : "Запис згоди",
    "Recording consent cannot be changed once a call or breakout session has started." : "Згоду на запис не можна змінити після початку дзвінка або секційної сесії.",
    "Require recording consent before joining call in this conversation" : "Вимагати згоди на запис перед тим, як приєднатися до розмови в цій розмові",
    "Recording consent is required for all calls" : "Згода на запис необхідна для всіх дзвінків",
    "SIP dial-in is now possible without PIN requirement" : "SIP-додзвін тепер можливий без запиту PIN-коду",
    "SIP dial-in is now enabled" : "SIP-додзвін увімкнено",
    "SIP dial-in is now disabled" : "SIP-додзвін вимкнено",
    "Error occurred when enabling SIP dial-in" : "Виникла помилка під час увімкнення SIP-дозвону",
    "Error occurred when disabling SIP dial-in" : "Виникла помилка при відключенні SIP-дозвону",
    "Phone and SIP dial-in" : "Телефонний та SIP-додзвін",
    "Enable phone and SIP dial-in" : "Увімкніть телефон і SIP-додзвін",
    "Allow to dial-in without a PIN" : "Дозвіл на вхід без PIN-коду",
    "Ongoing" : "Триває",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n осіб прийнято","%n осіб прийнято","%n осіб прийнято","%n осіб прийнято"],
    "_%n person declined_::_%n people declined_" : ["%n осіб відмовилися","%n людей відмовилися","%n людей відмовилися","%n людей відмовилися"],
    "_and %n other attachment_::_and %n other attachments_" : ["та %n інших вкладень","та %n інших вкладень","та %n інших вкладень","та %n інших вкладень"],
    "With {displayName}" : "З {displayName}",
    "In {conversation}" : "У {conversation}",
    "View attachment" : "Переглянути вкладення",
    "Join" : "Приєднатися",
    "View conversation" : "Переглянути розмову",
    "View event on Calendar" : "Переглянути подію в Календарі",
    "Error while creating the conversation" : "Помилка під час створення розмови",
    "Hello, {displayName}" : "Вітання, {displayName}",
    "Start meeting now" : "Почати зустріч",
    "Give your meeting a title" : "Дайте назву вашій зустрічі",
    "Create and copy link" : "Посилання на зустріч",
    "Create a new conversation" : "Створити нову розмову",
    "Join open conversations" : "Приєднуйтесь до відкритих розмов",
    "Call a phone number" : "Зателефонуйте за номером телефону",
    "Scroll backward" : "Прокрутити назад",
    "Scroll forward" : "Прокрутити вперед",
    "Schedule meetings" : "Заплануйте зустрічі",
    "You don't have any upcoming meetings" : "У вас немає найближчих зустрічей",
    "Open calendar" : "Відкрити календар",
    "Unread mentions" : "Непрочитані згадки",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Тут з'являться повідомлення, в яких вас згадували. Ви можете згадати людей, набравши @, а потім їхнє ім'я",
    "Upcoming reminders" : "Найближчі нагадування",
    "Message reminders" : "Нагадування про повідомлення",
    "Set a reminder on a message to be notified" : "Налаштування нагадування про повідомлення для сповіщення",
    "Start a group conversation" : "Почніть групову розмову",
    "Create conversation" : "Створити розмову",
    "Enter your name" : "Зазначте ваше ім'я",
    "Submit name and join" : "Введіть ім'я та приєднуйтесь",
    "Do you already have an account?" : "У вас вже є обліковий запис?",
    "Log in" : "Увійти",
    "Error while verifying uploaded file" : "Помилка при перевірці завантаженого файлу",
    "Uploaded file is verified" : "Завантажений файл перевірено",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Формат вмісту — значення, розділені комами (CSV):<br/>- Заголовок рядка є обов'язковим і повинен відповідати<samp>«name», «email»</samp>або просто<samp>«email»</samp><br/>- Один запис на рядок (наприклад, <samp>«John Doe», «john@example.tld»</samp>)",
    "Participants added successfully" : "Учасники успішно додані",
    "Error while adding participants" : "Помилка під час додавання учасників",
    "Import a file" : "Імпорт файлу",
    "Browse" : "Переглянути",
    "Verifying uploaded file …" : "Перевірка завантаженого файлу ...",
    "This might take a moment" : "Це може зайняти деякий час",
    "Send invitations" : "Надсилайте запрошення",
    "_%n invalid email_::_%n invalid emails_" : ["%n невірна адреса електронної пошти","%n недійсних імейлів","%n недійсних імейлів","%n недійсних імейлів"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n імейл вже імпортовано або є дублікатом","%n імейлів вже імпортовано або є дублікати","%n імейлів вже імпортовано або є дублікати","%n імейлів вже імпортовано або є дублікати"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n запрошень може бути надіслано","Можна надіслати %n запрошень","Можна надіслати %n запрошень","Можна надіслати %n запрошень"],
    "An error occurred while calling a phone number" : "Виникла помилка під час дзвінка на номер телефону",
    "Phone number could not be called: {error}" : "Не вдалося додзвонитися за номером телефону: {error}",
    "Phone number could not be called" : "За номером телефону не вдалося додзвонитися",
    "Search participants or phone numbers" : "Пошук учасників або номерів телефонів",
    "Creating the conversation …" : "Створення розмови ...",
    "Mark as read" : "Відмітити прочитаним",
    "Mark as unread" : "Позначити не прочитаним",
    "Remove from favorites" : "Прибрати зірочку",
    "Add to favorites" : "Додати зірочку",
    "Unarchive conversation" : "Неархівована розмова",
    "Ignore \"Do not disturb\"" : "Ігнорувати \"Не турбувати\"",
    "You need to promote a new moderator before you can leave the conversation." : "Перед тим, як вийти з розмови, вам потрібно призначити нового модератора.",
    "New tag" : "Нова мітка",
    "Tag name" : "Назва мітки",
    "Conversation actions" : "Розмовні дії",
    "Tags" : "Мітки",
    "Notify about calls" : "Сповіщати про дзвінки",
    "Hide message text" : "Приховати текст повідомлення",
    "Delete tag" : "Вилучити мітку",
    "Move up" : "Пересунуту догори",
    "Move down" : "Пересунути вниз",
    "Pending invitations" : "Очікують на запрошення",
    "From {user} at {remoteServer}" : "Від {user} за адресою {remoteServer}",
    "Decline invitation" : "Відхилити запрошення",
    "Accept invitation" : "Прийняти запрошення",
    "No pending invitations" : "Немає очікуваних запрошень",
    "Home" : "Домівка",
    "Unread" : "Непрочитане",
    "Mentions" : "Згадки",
    "Meetings" : "Зустрічі",
    "Alphabetically" : "Назва",
    "No followed threads" : "Немає потоків, за якими слідкують",
    "No matches found" : "Збігів не знайдено",
    "No conversations found" : "Розмов не знайдено",
    "You have no archived conversations." : "У вас немає архівних розмов.",
    "Subscribe to an existing thread or start your own." : "Підпишіться на існуючу тему або створіть власну.",
    "You have no unread mentions." : "У вас немає непрочитаних згадок.",
    "You have no unread messages." : "У вас немає непрочитаних повідомлень.",
    "An error occurred while performing the search" : "Помилка під час пошуку",
    "Conversation list" : "Список розмов",
    "Filter conversations by" : "Фільтруйте розмови за",
    "Unread messages" : "Непрочитані повідомлення",
    "Meeting conversations" : "Розмови на зустрічах",
    "Clear filters" : "Очистити фільтри",
    "New personal note" : "Нова особиста нотатка",
    "Back to conversations" : "Повернемося до розмов",
    "Threads" : "Гілки",
    "Archived conversations" : "Архівні розмови",
    "Clear filter" : "Очистити фільтр",
    "Show more threads" : "Показати більше тем",
    "App settings" : "Налаштування",
    "Users" : "Користувачі",
    "Groups" : "Групи",
    "Teams" : "Команди",
    "Federated users" : "Об'єднані користувачі",
    "New private conversation" : "Нова приватна розмова",
    "Other sources" : "Інші джерела",
    "Open conversations" : "Відкрити розмови",
    "No search results" : "Нічого не знайдено",
    "Users, groups and teams" : "Користувачі, групи та команди",
    "Users and groups" : "Користувачі та групи",
    "Users and teams" : "Користувачі та команди",
    "Groups and teams" : "Групи та команди",
    "New group conversation" : "Нова групова розмова",
    "The meeting will start soon" : "Зустріч незабаром розпочнеться",
    "This meeting is scheduled for {startTime}" : "Ця зустріч запланована на {startTime}",
    "You are currently waiting in the lobby" : "Чекаємо на схвалення доступу",
    "Advanced" : "Додатково",
    "Select microphone" : "Виберіть мікрофон",
    "No microphone available" : "Мікрофон відсутній",
    "Select speaker" : "Виберіть спікера",
    "No speaker available" : "Спікер відсутній",
    "Select camera" : "Виберіть камеру",
    "No camera available" : "Камера відсутня",
    "Select a device" : "Вибрати пристрій",
    "Playing …" : "Граю...",
    "Test speakers" : "Тестові колонки",
    "Test" : "Тест ",
    "Devices" : "Пристрої",
    "Backgrounds" : "Передумови",
    "No audio" : "Вимкнути мікрофон",
    "No camera" : "Вимкнути камеру",
    "Display video as you will see it (mirrored)" : "Відображати відео так, як ви його побачите (у дзеркальному відображенні)",
    "Display video as others will see it" : "Відображайте відео так, як його побачать інші",
    "Calls are not supported in your browser" : "Дзвінки не підтримуються у вашому браузері",
    "Access to microphone is only possible with HTTPS" : "Доступ до мікрофона можливий лише за допомогою HTTPS",
    "Access to microphone was denied" : "У доступі до мікрофону було відмовлено",
    "Error while accessing microphone" : "Помилка під час доступу до мікрофона",
    "Access to camera is only possible with HTTPS" : "Доступ до камери можливий лише через безпечний протокол HTTPS",
    "The call is being recorded." : "Розмова записується.",
    "The call might be recorded." : "Дзвінок може бути записаний.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Запис може містити ваш голос, відео з камери та скріншот. Перед тим, як приєднатися до дзвінка, потрібна ваша згода.",
    "Give consent to the recording of this call" : "Дайте згоду на запис цього дзвінка",
    "Show more info" : "Показати більше інформації",
    "Audio is not available" : "Аудіо недоступне",
    "Video is not available" : "Відео недоступне",
    "Start recording immediately with the call" : "Почніть запис одразу після дзвінка",
    "Notify all participants about this call" : "Повідомте всіх учасників про цей дзвінок",
    "Apply settings" : "Застосувати налаштування",
    "Select virtual office background" : "Виберіть фон віртуального офісу",
    "Select virtual home background" : "Виберіть фон віртуального будинку",
    "Select virtual abstract background" : "Виберіть віртуальний абстрактний фон",
    "Select virtual beach background" : "Виберіть віртуальне тло пляжу",
    "Select virtual park background" : "Виберіть фон віртуального парку",
    "Select virtual theater background" : "Виберіть фон віртуального театру",
    "Select virtual library background" : "Виберіть фон віртуальної бібліотеки",
    "Select virtual space station background" : "Виберіть фон віртуальної космічної станції",
    "Error while uploading the file" : "Помилка під час завантаження файлу",
    "Select a file" : "Виберіть файл",
    "Invalid path selected" : "Вибрано неправильний шлях",
    "Select virtual background from file {fileName}" : "Виберіть віртуальний фон з файлу {fileName}",
    "Blur" : "Розмиття",
    "Upload" : "Завантажити",
    "Files" : "Робота з файлами",
    "(editing)" : "(редагування)",
    "(edited)" : "(відредаговано)",
    "The message has expired or has been deleted" : "Термін дії повідомлення закінчився або його було видалено",
    "Cancel quote" : "Скасувати пропозицію",
    "24 hours" : "24 години",
    "7 days" : "7 днів",
    "Clear reminder – {timeLocale}" : "Чітке нагадування - {timeLocale}",
    "Edited by {actor}" : "За редакцією {actor}",
    "Message text copied to clipboard" : "Текст повідомлення скопійовано до буфера обміну",
    "Message text could not be copied" : "Текст повідомлення не вдалося скопіювати",
    "Message forwarded to \"Note to self\"" : "Повідомлення перенаправлено до \"Примітки для себе\"",
    "Error while forwarding message to \"Note to self\"" : "Помилка при пересиланні повідомлення до \"Примітки для себе\"",
    "A reminder was successfully removed" : "Нагадування успішно видалено",
    "Error occurred when removing a reminder" : "Виникла помилка при видаленні нагадування",
    "A reminder was successfully set at {datetime}" : "Нагадування було успішно встановлено за адресою {datetime}",
    "Error occurred when creating a reminder" : "Виникла помилка при створенні нагадування",
    "Add a reaction to this message" : "Додати реакцію на це повідомлення",
    "Reply" : "Відповісти",
    "More actions" : "Більше дій",
    "Set reminder" : "Встановити нагадування",
    "Reply privately" : "Відповісти у приватній розмові",
    "Edit message" : "Редагувати повідомлення",
    "Copy message" : "Скопіювати повідомлення",
    "Copy message link" : "Скопіювати посилання на повідомлення",
    "Go to file" : "Перейти до файлу",
    "Download file" : "Звантажити файл",
    "Go to thread" : "Перейти до теми",
    "Edit thread details" : "Редагування деталей теми",
    "Forward message" : "Переадресоване повідомлення",
    "Translate" : "Перекласти",
    "Set custom reminder" : "Встановити власне нагадування",
    "Close reactions menu" : "Закрити меню реакцій",
    "React with {emoji}" : "Відреагувати з {emoji}",
    "React with another emoji" : "Відреагувати з іншою {emoji}",
    "Choose a conversation to forward the selected message." : "Виберіть розмову, щоб переслати вибране повідомлення.",
    "Error while forwarding message" : "Помилка під час пересилання повідомлення",
    "The message has been forwarded to {selectedConversationName}" : "Повідомлення було надіслано на адресу {selectedConversationName}",
    "Dismiss" : "Припинити",
    "Go to conversation" : "Перейти до розмови",
    "Detect language" : "Визначити мову",
    "The message could not be translated" : "Повідомлення не вдалося перекласти",
    "Translation copied to clipboard" : "Переклад скопійовано до буфера обміну",
    "Translation could not be copied" : "Переклад не можна копіювати",
    "Translate message" : "Перекласти повідомлення",
    "Source language to translate from" : "Мова оригіналу для перекладу",
    "Translate from" : "Перекласти з",
    "Target language to translate into" : "Цільова мова для перекладу",
    "Translate to" : "Перекласти",
    "Translating" : "Переклад",
    "Copy translated text" : "Скопіювати перекладений текст",
    "Send now" : "Надіслати зараз",
    "Message read by everyone who shares their reading status" : "Повідомлення читають усі, хто ділиться своїм статусом читання",
    "Message sent" : "Повідомлення відправлено",
    "Sent without notification" : "Відправлено без попередження",
    "Deleting message" : "Видалення повідомлення",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Повідомлення успішно видалено, але бот або Matterbridge налаштовано, і повідомлення вже може бути розповсюджено на інші сервіси",
    "Message deleted successfully" : "Повідомлення успішно видалено",
    "Message could not be deleted because it is too old" : "Повідомлення не вдалося видалити, оскільки воно занадто старе",
    "Only normal chat messages can be deleted" : "Вилучасти можна лише звичайні повідомлення чату",
    "An error occurred while deleting the message" : "Виникла помилка під час видалення повідомлення",
    "Your browser does not support playing audio files" : "Ваш браузер не підтримує відтворення аудіофайлів",
    "Contact" : "Контакт",
    "{stack} in {board}" : "{stack} в {board}",
    "Deck Card" : "Карта з колоди",
    "Remove {fileName}" : "Вилучити {fileName}",
    "Open this location in OpenStreetMap" : "Відкрийте це місце на OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n відповідь","%n відповідей","%n відповідей","%n відповідей"],
    "Sending message" : "Надсилання повідомлення",
    "Failed to send the message. Click to try again" : "Не вдалося відправити повідомлення. Натисніть, щоб спробувати ще раз",
    "Not enough free space to upload file" : "Недостатньо місця для завантаження файлу",
    "You cannot send messages to this conversation at the moment" : "Наразі ви не можете надсилати повідомлення до цієї розмови",
    "Could not update the message" : "Не вдалося оновити повідомлення",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Проект опитування - %n варіант","Проект опитування - %n варіантів","Проект опитування - %n варіантів","Проект опитування - %n варіантів"],
    "_%n vote_::_%n votes_" : ["%n голосів","%n голосів","%n голосів","%n голосів"],
    "Edit poll draft" : "Редагувати чернетку опитування",
    "Delete poll draft" : "Видалити проект опитування",
    "Open poll" : "Відкрите опитування",
    "See results" : "Переглянути результати",
    "Reactions" : "Реакції",
    "No permission to post reactions in this conversation" : "Немає дозволу публікувати реакції в цій розмові",
    "and {participant}" : "і {participant}",
    "_and %n other participant_::_and %n other participants_" : ["та %n інших учасників","та %n інших учасників","та %n інших учасників","та %n інших учасників"],
    "Show all reactions" : "Показати всі реакції",
    "Add more reactions" : "Додайте більше реакцій",
    "Show or collapse system messages" : "Показати або згорнути системні повідомлення",
    "No messages" : "Відсутні повідомлення",
    "All messages have expired or have been deleted." : "Всі повідомлення втратили актуальність або були видалені.",
    "Unpin" : "Відкріпити",
    "Cancel search" : "Зупинити пошук",
    "Add a phone number" : "Додати номер телефону",
    "Error: A password is required to create the conversation." : "Помилка: Для створення розмови потрібен пароль.",
    "All set, the conversation \"{conversationName}\" was created." : "Все готово, розмова \"{conversationName}\" створена.",
    "Create a new group conversation" : "Створити нову групову розмову",
    "Add participants" : "Додати учасників",
    "Maximum length exceeded ({maxlength} characters)" : "Перевищено максимальну довжину ({maxlength} символів)",
    "Conversation visibility" : "Видимість розмови",
    "Allow guests to join via link" : "Дозволити гостям приєднатися за посиланням",
    "Enter password" : "Введіть пароль",
    "This conversation has been locked" : "Ця розмова була заблокована",
    "No permission to post messages in this conversation" : "Немає дозволу на розміщення повідомлень у цій бесіді",
    "Joining conversation …" : "Приєднуйтесь до розмови ...",
    "Write a message without notification" : "Написати повідомлення без попередження",
    "Create a thread silently" : "Створити гілку приховано",
    "Create a thread" : "Створіть тему",
    "Send message silently" : "Надіслати повідомлення без звуку",
    "Send message" : "Надіслати повідомлення",
    "Send without notification" : "Надіслати без попередження",
    "The participant will not be notified about new messages" : "Учасник не буде отримувати сповіщення про нові повідомлення",
    "Participants will not be notified about new messages" : "Учасники не будуть отримувати сповіщення про нові повідомлення",
    "Thread title is required" : "Назва теми обов'язкова",
    "Message text is required" : "Текст повідомлення є обов'язковий",
    "The message could not be edited" : "Повідомлення не вдалося відредагувати",
    "File to share" : "Виберіть файл для надання доступу",
    "File upload is not available in this conversation" : "Завантаження файлів недоступне в цій розмові",
    "Add emoji" : "Додати емоційку",
    "Adding a mention will only notify users who did not read the message." : "Додавання згадки сповістить лише тих користувачів, які не читали повідомлення.",
    "Thread title" : "Назва гілки",
    "Send later" : "Надішліть пізніше",
    "Cancel editing" : "Скасувати редагування",
    "{user} is out of office and might not respond." : "{user} перебуває у відставці і може не відповісти.",
    "Absence period: {startDate} - {endDate}" : "Період відсутності: {startDate} - {endDate}",
    "Replacement:" : "Заміна:",
    "Share from {nextcloud}" : "Поділітися з {nextcloud}",
    "Share from Files" : "Відкрити Файли",
    "Share files to the conversation" : "Поділитися файлами під час розмови",
    "Upload from device" : "Завантажити з пристрою",
    "Create new poll" : "Створити нове опитування",
    "Smart picker" : "Асистент розумного вибору",
    "Record voice message" : "Записати голосове повідомлення",
    "End recording and send" : "Завершити запис і відправити",
    "Dismiss recording" : "Зняти запис",
    "Access to the microphone was denied" : "У доступі до мікрофону було відмовлено",
    "Microphone either not available or disabled in settings" : "Мікрофон або недоступний, або вимкнений у налаштуваннях",
    "Error while recording audio" : "Помилка під час запису аудіо",
    "Generating summary of unread messages …" : "Створення зведення непрочитаних повідомлень ...",
    "Summary is AI generated and might contain mistakes" : "Резюме згенероване штучним інтелектом і може містити помилки",
    "Error occurred during a summary generation" : "Виникла помилка під час формування звіту",
    "New file" : "Новий файл",
    "Blank" : "Порожньо",
    "Error while creating file" : "Помилка під час створення файлу",
    "Create and share a new file" : "Створіть і надайте спільний доступ до нового файлу",
    "Name of the new file" : "Ім'я нового файлу",
    "Create file" : "Створити файл",
    "Someone is typing …" : "Хтось друкує ...",
    "{user1} is typing …" : "{user1} друкує ...",
    "{user1} and {user2} are typing …" : "{user1} і {user2} набирають ...",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} та {user3} друкують ...",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} та %n інших набирають ...","{user1}, {user2}, {user3} та %n інших набирають ...","{user1}, {user2}, {user3} та %n інших набирають ...","{user1}, {user2}, {user3} та %n інших набирають ..."],
    "Add more files" : "Додайте більше файлів",
    "Send" : "Надіслати",
    "In this conversation <strong>{user}</strong> can:" : "У цій розмові <strong>{user}</strong> може:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Редагування дозволів за замовчуванням для учасників у <strong> {conversationName}</strong>",
    "Start a call" : "Почати дзвінок",
    "Skip the lobby" : "Пропустити зал очікування",
    "Can post messages and reactions" : "Можна публікувати повідомлення та реакції",
    "Enable the microphone" : "Вмикати мікрофон",
    "Enable the camera" : "Вмикати камеру",
    "Share the screen" : "Ділитися екраном",
    "Update permissions" : "Оновити дозволи",
    "Updating permissions" : "Оновлення дозволів",
    "No poll drafts" : "Немає чернеток опитувань",
    "There is no poll drafts yet saved for this conversation" : "Для цієї розмови ще не збережено чернеток опитувань",
    "Create poll in {name}" : "Створіть опитування в {name}",
    "Create poll" : "Створити опитування",
    "Error while importing poll" : "Помилка під час імпорту опитування",
    "Question" : "Питання",
    "Ask a question" : "Поставити запитання",
    "Import draft from file" : "Імпортувати чернетку з файлу",
    "Answers" : "Відповіді",
    "Answer {option}" : "Відповідай. {option}",
    "Delete poll option" : "Видалити варіант опитування",
    "Add answer" : "Додати відповідь",
    "Settings" : "Налаштування",
    "Anonymous poll" : "Анонімне опитування",
    "Multiple answers" : "Декілька відповідей",
    "Save as draft" : "Зберегти як чернетку",
    "Export draft to file" : "Експортуйте чернетку до файлу",
    "You voted for this option" : "Ви проголосували за цей варіант",
    "End poll" : "Завершити опитування",
    "Change your vote" : "Змініть свій голос",
    "Results" : "Результат",
    "Voted participants" : "Проголосували учасники",
    "Send a message to \"{roomName}\"" : "Надішліть повідомлення на \"{roomName}\"",
    "Hide list of participants" : "Приховати список учасників",
    "Show list of participants" : "Показати список учасників",
    "Assistance requested in {roomName}" : "Прохання про допомогу в {roomName}",
    "The message was sent to \"{roomName}\"" : "Повідомлення було надіслано на адресу \"{roomName}\"",
    "Dismiss request for assistance" : "Відхилити запит на допомогу",
    "Send message to room" : "Надіслати повідомлення в номер",
    "Back to main room" : "Повернутися до головної кімнати",
    "Back to your room" : "Поверніться до своєї кімнати",
    "Message all rooms" : "Повідомлення на всі номери",
    "Start session" : "Початок сесії",
    "Start a call before you start a breakout room session" : "Почніть виклик, перш ніж запустити сесію в кімнатах обговорення",
    "Stop session" : "Зупинити сеанс",
    "The message was sent to all breakout rooms" : "Повідомлення було надіслано до всіх секційних кімнат",
    "Send a message to all breakout rooms" : "Надіслати повідомлення до всіх секційних кімнат",
    "Breakout rooms are not started" : "Розділені кімнати не запущено.",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Дзвінки без високопродуктивного бекенду можуть спричинити проблеми зі зв'язком і високе навантаження на пристрої. {linkstart}Дізнайтеся більше{linkend}",
    "Talk setup incomplete" : "Налаштування розмови не завершено",
    "Disable lobby" : "Вимкнути лобі",
    "Settings for participant \"{user}\"" : "Налаштування для учасника \"{user}\"",
    "Participant \"{user}\"" : "Учасник \"{user}",
    "moderator" : "модератор",
    "bot" : "бот",
    "guest" : "гість",
    "Ringing …" : "Дзвінок...",
    "Call rejected" : "Виклик відхилено",
    "{time} talking …" : "{time} розмовляє ...",
    "{time} talking time" : "{time} час розмови",
    "Raised their hand" : "Підняли руку",
    "Joined with video" : "Приєднано до відео",
    "Joined via phone" : "Приєднався по телефону",
    "Joined with audio" : "Приєднано до аудіо",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Текст повинен мати довжину не менше або дорівнювати {maxLength} символів. Ваш поточний текст має довжину {charactersCount} символів.",
    "Remove group and members" : "Вилучити групи та учасників",
    "Remove team and members" : "Видалити команду та учасників",
    "Remove participant" : "Вилучити учасника",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Ви дійсно хочете видалити групу \"{displayName}\" та її учасників з цієї розмови?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Ви дійсно хочете видалити команду \"{displayName}\" та її членів з цієї розмови?",
    "Do you really want to remove {displayName} from this conversation?" : "Ви дійсно хочете видалити {displayName} з цієї розмови?",
    "Notification was sent to {displayName}" : "Повідомлення було надіслано на адресу {displayName}",
    "Could not send notification to {displayName}" : "Не вдалося надіслати сповіщення на адресу {displayName}",
    "Permissions granted to {displayName}" : "Дозволи, надані для {displayName}",
    "Could not modify permissions for {displayName}" : "Не вдалося змінити дозволи для {displayName}",
    "Permissions removed for {displayName}" : "Дозволи вилучено для {displayName}",
    "Permissions set to default for {displayName}" : "Дозволи, встановлені за замовчуванням для {displayName}",
    "Phone number could not be hung up" : "Номер телефону не вдалося покласти слухавку",
    "Phone number could not be put on hold" : "Номер телефону не вдалося перевести на утримання",
    "Phone number could not be muted" : "Номер телефону не можна вимкнути",
    "Phone number could not be unmuted" : "Номер телефону не можна було вимкнути",
    "DTMF message could not be sent" : "Не вдалося надіслати DTMF-повідомлення",
    "Phone number copied to clipboard" : "Номер телефону скопійовано до буфера обміну",
    "Phone number could not be copied" : "Номер телефону не вдалося скопіювати",
    "in the lobby" : "у вестибюлі",
    "Dial out phone" : "Наберіть номер телефону",
    "Hang up phone" : "Покладіть слухавку.",
    "Move back to lobby" : "Поверніться до вестибюлю",
    "Move to conversation" : "Переходимо до розмови",
    "Dial-in PIN" : "PIN-код для входу в систему",
    "Demote from moderator" : "Розжалування з модератора",
    "Promote to moderator" : "Призначити модератором",
    "Resend invitation" : "Повторно надіслати запрошення",
    "Send call notification" : "Надіслати сповіщення про дзвінок",
    "Dial out phone number" : "Наберіть номер телефону",
    "Resume call for phone number" : "Відновити дзвінок за номером телефону",
    "Put phone number on hold" : "Поставити номер телефону на утримання",
    "Unmute phone number" : "Вимкнути звук телефону",
    "Mute phone number" : "Вимкнення звуку номера телефону",
    "Copy phone number" : "Скопіювати номер телефону",
    "Reset custom permissions" : "Скидання користувацьких дозволів",
    "Grant all permissions" : "Надати всі дозволи",
    "Remove all permissions" : "Вилучити всі дозволи",
    "Also ban from this conversation" : "Також заборона на цю розмову",
    "Internal note (reason to ban)" : "Внутрішня примітка (причина заборони)",
    "Remove" : "Вилучити",
    "Permissions modified for {displayName}" : "Дозволи змінено для {displayName}",
    "Add users, groups or teams" : "Додавання користувачів, груп або команд",
    "Add users or groups" : "Додати користувачів або групи",
    "Add users or teams" : "Додавання користувачів або команд",
    "Add users" : "Додати користувачів",
    "Add groups or teams" : "Додавання груп або команд",
    "Add groups" : "Додати групи",
    "Add teams" : "Додати команду",
    "Add other sources" : "Додайте інші джерела",
    "Add emails" : "Додати email-адреси",
    "Integrations" : "Інтеграції",
    "Add federated users" : "Додавання об'єднаних користувачів",
    "Searching …" : "Пошук...",
    "Search for more users" : "Шукати інших користувачів",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Ви можете шукати або додавати учасників за іменем, електронною поштою або ідентифікатором Federated Cloud ID",
    "Search or add participants" : "Пошук або додавання учасників",
    "Invitation was sent to {actorId}" : "Запрошення було надіслано {actorId}",
    "An error occurred while adding the participants" : "Виникла помилка під час додавання учасників",
    "A new group conversation with selected participant will be created" : "Буде створено нову групову розмову з обраним учасником",
    "Participants" : "Учасники",
    "Participants ({count})" : "Учасники ({count})",
    "Open chat" : "Відкритий чат",
    "You have new unread messages in the chat." : "У вас є нові непрочитані повідомлення в чаті.",
    "You have been mentioned in the chat." : "Ви були згадані в чаті.",
    "Search messages" : "Пошук повідомлень",
    "Chat" : "Чат",
    "Details" : "Деталі",
    "Shared items" : "Спільні ресурси",
    "Search in {name}" : "Шукати в {name}",
    "Threads in {name}" : "Гілки у {name}",
    "{actor} in {conversation}" : "{actor} в {conversation}",
    "Search messages …" : "Пошук повідомлень ...",
    "Search options" : "Параметри пошуку",
    "From User" : "Від користувача",
    "Since" : "Оскільки",
    "Until" : "До тих пір, поки",
    "No results found" : "Не знайдено жодного результату",
    "Load more results" : "Завантажити більше результатів",
    "Recent threads" : "Останні теми",
    "Projects" : "Проєкти",
    "No shared items" : "Немає спільних елементів",
    "Thread notifications" : "Сповіщення про потоки",
    "Thread actions" : "Дії з нитками",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Посилання на розмову",
    "No open conversations found" : "Не знайдено жодної відкритої розмови",
    "Either there are no open conversations or you joined all of them." : "Або немає відкритих розмов, або ви приєдналися до всіх.",
    "Check spelling or use complete words." : "Перевірте правопис або використовуйте повні слова.",
    "Search conversations or users" : "Пошук розмов та учасників",
    "Select conversation" : "Вибрати розмову",
    "Number length is not valid" : "Довжина номера не допустима",
    "Region code is not valid" : "Регіональний код не дійсний",
    "Number length is too short" : "Занадто коротка довжина номера",
    "Number length is too long" : "Довжина номера занадто велика",
    "Number is not valid" : "Номер недійсний",
    "Phone numbers" : "Номери телефонів",
    "Display name: {name}" : "Ім'я для показу: {name}",
    "Edit display name" : "Редагувати ім'я для показу",
    "Display name (required)" : "Відображати ім'я (обов'язково)",
    "Save name" : "Зберегти ім'я",
    "Error while setting personal setting" : "Помилка під час встановлення персональних налаштувань",
    "Error while saving sounds setting" : "Помилка під час збереження налаштування звуків",
    "Play sounds when participants join or leave a call" : "Коли учасники приєднуються до дзвінка або виходять з нього, відтворювати звуковий сигнал",
    "Notification settings" : "Налаштування сповіщень",
    "Default language" : "Типова мова",
    "Select location for attachments" : "Виберіть місце для вкладень",
    "Error while setting attachment folder" : "Помилка під час встановлення папки вкладення",
    "Error while setting read status privacy" : "Помилка під час встановлення конфіденційності статусу читання",
    "Error while setting typing status privacy" : "Помилка під час встановлення конфіденційності статусу набору тексту",
    "Error while setting default media state" : "Помилка під час встановлення стану носія за замовчуванням",
    "Privacy" : "Конфіденційність",
    "Attachments folder" : "Каталог із вкладеннями",
    "Toggle full screen" : "Розгорнути на весь екран",
    "Search" : "Пошук",
    "Focus the chat input" : "Фокусування вводу в чаті",
    "Unfocus the chat input to use shortcuts" : "Розфокусувати введення в чаті, щоб використовувати комбінації клавіш",
    "Edit your last message" : "Відредагуйте своє останнє повідомлення",
    "Shortcuts while in a call" : "Швидкі клавіші під час дзвінка",
    "Camera on and off" : "Увімкнення та вимкнення камери",
    "Microphone on and off" : "Увімкнення та вимкнення мікрофона",
    "Raise or lower hand" : "Підняти або опустити руку",
    "Push to talk or push to mute" : "Натисніть, щоб почати говорити, або тисніть, щоб вимкнути звук",
    "Zoom-in / zoom-out a screen share" : "Збільшення/зменшення масштабу спільного доступу до екрана",
    "Mouse wheel" : "Коліщатко миші",
    "Start call silently" : "Почніть дзвінок беззвучно",
    "Start call" : "Почати виклик",
    "End call" : "Кінець зв'язку.",
    "This call has just ended" : "Цей дзвінок щойно закінчився",
    "You will be able to join the call only after a moderator starts it." : "Ви зможете приєднатися до дзвінка лише після того, як його розпочне модератор.",
    "End call for everyone" : "Завершити дзвінок для всіх",
    "Starting the recording" : "Початок запису",
    "Recording" : "Запис",
    "The call has been running for one hour." : "Дзвінок триває вже годину.",
    "Cancel recording start" : "Скасувати початок запису",
    "Stop recording" : "Зупинити запис",
    "Raise hand" : "Підняти руку",
    "Raise hand (R)" : "Підняти руку (R)",
    "Lower hand" : "Опустити руку",
    "Lower hand (R)" : "Нижня рука (R)",
    "Send a reaction" : "Надішліть реакцію",
    "React with {reaction}" : "Реагуйте з {reaction}",
    "All tasks done!" : "Всі завдання виконані!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} від %n завдань","{done} з %n завдань","{done} з %n завдань","{done} з %n завдань"],
    "Add participants to this call" : "Додайте учасників до цього дзвінка",
    "_%n participant in call_::_%n participants in call_" : ["%n учасників дзвінка","%n учасників дзвінка","%n учасників дзвінка","%n учасників дзвінка"],
    "You are not allowed to enable screensharing" : "Ви не маєте права ввімкнути спільний доступ до екрана",
    "No screensharing" : "Без скріншотів",
    "Screensharing options" : "Параметри демонстрації екрану",
    "Enable screensharing" : "Увімкнути демонстрацію екрану",
    "Bad sent video and screen quality." : "Погана якість надісланого відео та екрану.",
    "Bad sent screen quality." : "Погана якість надісланого екрану.",
    "Bad sent video quality." : "Погана якість надісланого відео.",
    "Bad sent audio, video and screen quality." : "Погана якість надісланого аудіо, відео та екрану.",
    "Bad sent audio and screen quality." : "Погана якість надісланого аудіо та екрану.",
    "Bad sent audio and video quality." : "Погана якість надісланих аудіо та відео.",
    "Bad sent audio quality." : "Погана якість надісланого аудіо.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Ваше інтернет-з'єднання або комп'ютер перевантажені, і інші учасники можуть не бачити ваш екран. Щоб покращити ситуацію, спробуйте вимкнути розмиття фону або відео під час демонстрації екрана.",
    "Disable background blur" : "Вимкнути розмиття фону",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Ваше інтернет-з'єднання або комп'ютер завантажені, і інші учасники можуть не бачити ваш екран. Щоб поліпшити ситуацію, спробуйте вимкнути відео під час спільного використання екрана.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Ваше інтернет-з'єднання або комп'ютер зайняті, і інші учасники можуть не бачити ваш екран.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Ваше інтернет-з'єднання або комп'ютер зайняті, і інші учасники можуть не бачити вас.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Ваше інтернет-з'єднання або комп'ютер завантажені, і інші учасники можуть не бачити вас і не чути. Щоб поліпшити ситуацію, спробуйте вимкнути розмиття фону або відео під час спільного використання екрана.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Ваше інтернет-з'єднання або комп'ютер завантажені, і інші учасники можуть не бачити вас і не чути. Щоб поліпшити ситуацію, спробуйте вимкнути відео під час спільного використання екрана.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Ваше інтернет-з'єднання або комп'ютер завантажені, і інші учасники можуть не чути вас і не бачити ваш екран. Щоб поліпшити ситуацію, спробуйте вимкнути функцію спільного доступу до екрана.",
    "Disable screenshare" : "Вимкнути скріншот",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Ваше інтернет-з'єднання або комп'ютер завантажені, і інші учасники можуть не бачити вас і не чути. Щоб поліпшити ситуацію, спробуйте вимкнути розмиття фону або відео.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Ваше інтернет-з'єднання або комп'ютер завантажені, і інші учасники можуть не бачити вас і не чути. Щоб поліпшити ситуацію, спробуйте вимкнути відео.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Ваше інтернет-з'єднання або комп'ютер зайняті, і інші учасники можуть не зрозуміти вас.",
    "Screen sharing is not supported by your browser." : "Ваш браузер не підтримує демонстрацію екрана.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Демонстрація екрану вимагає доступу до сторінки через безпечний протокол https.",
    "Screensharing requires the page to be loaded through HTTPS." : "Демонстрація екрану вимагає доступу до сторінки через безпечний протокол https.",
    "An error occurred while starting screensharing." : "Помилка під час спроби поділитися екраном.",
    "Select virtual background" : "Виберіть віртуальний фон",
    "Show your screen" : "Демонстрація екрану",
    "Stop screensharing" : "Припинити демонстрацію екрану",
    "Mute others" : "Приглушити інших",
    "Start recording" : "Почати запис",
    "Set up breakout rooms" : "Підготуйте кімнати для секційних засідань",
    "Download attendance list" : "Завантажити список відвідувачів",
    "Open Calendar" : "Відкрити календар",
    "Remove participant {name}" : "Видалити учасника {name}",
    "Would you like to delete this conversation?" : "Ви хочете видалити цю розмову?",
    "Are you sure you want to delete this conversation?" : "Ви впевнені, що хочете видалити цю розмову?",
    "Delete now" : "Видалити зараз",
    "Keep" : "Зберегти",
    "Open dialpad" : "Відкрийте телефонну книгу",
    "Select a region" : "Виберіть регіон",
    "Local time: {time}" : "Місцевий час: {time}",
    "Search …" : "Пошук …",
    "Message without mention" : "Повідомлення без згадки",
    "Mention myself" : "Згадати про себе",
    "Mention everyone" : "Згадайте всіх",
    "Select a conversation" : "Виберіть розмову",
    "Select a mode" : "Виберіть режим",
    "You do not have permissions to access this conversation." : "Ви не маєте дозволів для доступу до цієї розмови.",
    "Join a different conversation or start a new one." : "Приєднайтеся до іншої розмови або почніть нову.",
    "The conversation does not exist" : "Розмови не існує",
    "Join a conversation or start a new one!" : "Приєднайтеся до розмови або почніть нову!",
    "Creating and joining a conversation with \"{userid}\"" : "Створення та приєднання до розмови з \"{userid}\"",
    "Join a conversation or start a new one" : "Приєднайтеся до розмови або почніть нову",
    "Error while joining the conversation" : "Помилка під час приєднання до розмови",
    "Nextcloud URL" : "URL-адреса наступної хмари",
    "Nextcloud user" : "Користувач Nextcloud",
    "User password" : "Пароль користувача",
    "Talk conversation" : "Розмова Talk",
    "Skip TLS verification" : "Пропустити перевірку TLS",
    "Matrix server URL" : "URL-адреса сервера матриці",
    "User" : "Користувач",
    "Matrix channel" : "Матричний канал",
    "Mattermost server URL" : "Найважливіша URL-адреса сервера",
    "Mattermost user" : "Найважливіший користувач",
    "Team name" : "Назва команди",
    "Channel name" : "Назва каналу",
    "Rocket.Chat server URL" : "Адреса сервера Rocket.Chat",
    "User name or email address" : "Ім'я користувача або адреса ел. пошти",
    "Rocket.Chat channel" : "Канал Rocket.Chat",
    "Zulip server URL" : "URL-адреса сервера Zulip",
    "Bot user name" : "Ім'я користувача бота",
    "Bot API key" : "Ключ API бота",
    "Zulip channel" : "Канал Zulip",
    "API token" : "Токен API",
    "Slack channel" : "Слабкий канал",
    "Server ID or name" : "Ідентифікатор або ім'я сервера",
    "Channel ID (prefixed with \"ID:\") or name" : "Ідентифікатор каналу (з префіксом \"ID:\") або назва",
    "Channel" : "Канал",
    "Login" : "Login",
    "Chat ID" : "Ідентифікатор чату",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL-адреса IRC-сервера (наприклад, chat.freenode.net:6667)",
    "Nickname" : "Прізвисько",
    "Connection password" : "Пароль для підключення",
    "IRC channel" : "IRC-канал",
    "Channel password" : "Пароль каналу",
    "NickServ nickname" : "NickServ нікнейм",
    "NickServ password" : "Пароль NickServ",
    "Use TLS" : "Використовуйте TLS",
    "Use SASL" : "Використовуйте SASL",
    "Tenant ID" : "Ідентифікатор орендаря",
    "Client ID" : "Ідентифікатор клієнта",
    "Team ID" : "Ідентифікатор команди",
    "Thread ID" : "Ідентифікатор гілки",
    "XMPP/Jabber server URL" : "URL-адреса сервера XMPP/Jabber",
    "MUC server URL" : "URL-адреса сервера MUC",
    "Jabber ID" : "Jabber ID",
    "Media" : "Зображення та відео",
    "Polls" : "Опитування",
    "Deck cards" : "Карти з колоди",
    "Voice messages" : "Голосові повідомлення",
    "Locations" : "Розташування",
    "Call recordings" : "Записи дзвінків",
    "Audio" : "Аудіо",
    "Show all media" : "Показати всі медіа",
    "Show all files" : "Показати всі файли",
    "Show all polls" : "Показати всі опитування",
    "Show all deck cards" : "Показати всі карти колоди",
    "Show all voice messages" : "Показати всі голосові повідомлення",
    "Show all locations" : "Показати всі локації",
    "Show all call recordings" : "Показати всі записи дзвінків",
    "Show all audio" : "Показати всі аудіо",
    "Show all other" : "Показати всі інші",
    "Follow conversation settings" : "Слідкувати за налаштуваннями розмови",
    "Group" : "Група",
    "Team" : "Команда",
    "You reconnected to the call" : "Ви знову підключилися до дзвінка",
    "{actor} reconnected to the call" : "{actor} перепідключився до виклику",
    "You added {user0} and {user1}" : "Ви додали {user0} та {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Ви додали {user0}, {user1} та ще %n учасників","Ви додали {user0}, {user1} та ще %n учасників","Ви додали {user0}, {user1} та ще %n учасників","Ви додали {user0}, {user1} та ще %n учасників"],
    "An administrator added you and {user0}" : "Адміністратор додав вас і {user0}",
    "{actor} added you and {user0}" : "{actor} додав тебе і {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Адміністратор додав вас, {user0} та ще %n учасників","Адміністратор додав вас, {user0} та ще %n учасників","Адміністратор додав вас, {user0} та ще %n учасників","Адміністратор додав вас, {user0} та ще %n учасників"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} додали вас, {user0} та ще %n учасників","{actor} додали вас, {user0} та ще %n учасників","{actor} додали вас, {user0} та ще %n учасників","{actor} додали вас, {user0} та ще %n учасників"],
    "An administrator added {user0} and {user1}" : "Адміністратор додав {user0} та {user1}",
    "{actor} added {user0} and {user1}" : "{actor} додано {user0} та {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Адміністратор додав {user0}, {user1} та ще %n учасників","Адміністратор додав {user0}, {user1} та ще %n учасників","Адміністратор додав {user0}, {user1} та ще %n учасників","Адміністратор додав {user0}, {user1} та ще %n учасників"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} додано {user0}, {user1} та ще %n учасників","{actor} додано {user0}, {user1} та ще %n учасників","{actor} додано {user0}, {user1} та ще %n учасників","{actor} додано {user0}, {user1} та ще %n учасників"],
    "You removed {user0} and {user1}" : "Ви видалили {user0} та {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Ви видалили {user0}, {user1} та ще %n учасників","Ви видалили {user0}, {user1} та ще %n учасників","Ви видалили {user0}, {user1} та ще %n учасників","Ви видалили {user0}, {user1} та ще %n учасників"],
    "An administrator removed you and {user0}" : "Адміністратор видалив вас і {user0}",
    "{actor} removed you and {user0}" : "{actor} прибрали тебе і {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Адміністратор видалив вас, {user0} та ще %n учасників","Адміністратор видалив вас, {user0} та ще %n учасників","Адміністратор видалив вас, {user0} та ще %n учасників","Адміністратор видалив вас, {user0} та ще %n учасників"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} видалив вас, {user0} та ще %n учасників","{actor} видалили вас, {user0} та ще %n учасників","{actor} видалили вас, {user0} та ще %n учасників","{actor} видалили вас, {user0} та ще %n учасників"],
    "An administrator removed {user0} and {user1}" : "Адміністратор видалив {user0} та {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} видалено {user0} та {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Адміністратор видалив {user0}, {user1} та ще %n учасників","Адміністратор видалив {user0}, {user1} та ще %n учасників","Адміністратор видалив {user0}, {user1} та ще %n учасників","Адміністратор видалив {user0}, {user1} та ще %n учасників"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} видалено {user0}, {user1} та ще %n учасників","{actor} видалено {user0}, {user1} та ще %n учасників","{actor} видалено {user0}, {user1} та ще %n учасників","{actor} видалено {user0}, {user1} та ще %n учасників"],
    "You and {user0} joined the call" : "Ви та {user0} долучилися до заклику",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Ви, {user0} та ще %n учасників долучилися до конкурсу","Ви, {user0} та ще %n учасників долучилися до конкурсу","Ви, {user0} та ще %n учасників долучилися до конкурсу","Ви, {user0} та ще %n учасників долучилися до конкурсу"],
    "{user0} and {user1} joined the call" : "{user0} та {user1} приєдналися до заклику",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} та ще %n учасників долучилися до конкурсу","{user0}, {user1} та ще %n учасників долучилися до заклику","{user0}, {user1} та ще %n учасників долучилися до заклику","{user0}, {user1} та ще %n учасників долучилися до заклику"],
    "You and {user0} left the call" : "Ви та {user0} залишили повідомлення",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Ви, {user0} та ще %n учасників залишили дзвінок","Ви, {user0} та ще %n учасників залишили повідомлення","Ви, {user0} та ще %n учасників залишили повідомлення","Ви, {user0} та ще %n учасників залишили повідомлення"],
    "{user0} and {user1} left the call" : "{user0} і {user1} залишив дзвінок",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} і ще %n учасників залишили дзвінок","{user0}, {user1} та ще %n учасників відповіли на дзвінок","{user0}, {user1} та ще %n учасників відповіли на дзвінок","{user0}, {user1} та ще %n учасників відповіли на дзвінок"],
    "You promoted {user0} and {user1} to moderators" : "Ви призначили {user0} та {user1} модераторами",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Ви підвищили {user0}, {user1} та ще %n учасників до рівня модераторів","Ви підвищили {user0}, {user1} та ще %n учасників до рівня модераторів","Ви підвищили {user0}, {user1} та ще %n учасників до рівня модераторів","Ви підвищили {user0}, {user1} та ще %n учасників до рівня модераторів"],
    "An administrator promoted you and {user0} to moderators" : "Адміністратор призначив вас і {user0} модераторами",
    "{actor} promoted you and {user0} to moderators" : "{actor} підвищили вас і {user0} до модераторів",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Адміністратор підвищив вас, {user0} та ще %n учасників до рівня модераторів","Адміністратор підвищив вас, {user0} та ще %n учасників до рівня модераторів","Адміністратор підвищив вас, {user0} та ще %n учасників до рівня модераторів","Адміністратор підвищив вас, {user0} та ще %n учасників до рівня модераторів"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} підвищили вас, {user0} та ще %n учасників до модераторів","{actor} підвищили вас, {user0} та ще %n учасників до модераторів","{actor} підвищили вас, {user0} та ще %n учасників до модераторів","{actor} підвищили вас, {user0} та ще %n учасників до модераторів"],
    "An administrator promoted {user0} and {user1} to moderators" : "Адміністратор підвищив {user0} та {user1} до рівня модераторів",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} підвищили {user0} та {user1} до рівня модераторів",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Адміністратор підвищив {user0}, {user1} та ще %n учасників до рівня модераторів","Адміністратор підвищив {user0}, {user1} та ще %n учасників до рівня модераторів","Адміністратор підвищив {user0}, {user1} та ще %n учасників до рівня модераторів","Адміністратор підвищив {user0}, {user1} та ще %n учасників до рівня модераторів"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} підвищили {user0}, {user1} та ще %n учасників до рівня модераторів","{actor} просунули {user0}, {user1} та ще %n учасників до модераторів","{actor} просунули {user0}, {user1} та ще %n учасників до модераторів","{actor} просунули {user0}, {user1} та ще %n учасників до модераторів"],
    "You demoted {user0} and {user1} from moderators" : "Ви понизили {user0} та {user1} з модераторів",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Ви понизили {user0}, {user1} і ще %n учасників з модераторів","Ви понизили {user0}, {user1} та ще %n учасників з модераторів","Ви понизили {user0}, {user1} та ще %n учасників з модераторів","Ви понизили {user0}, {user1} та ще %n учасників з модераторів"],
    "An administrator demoted you and {user0} from moderators" : "Адміністратор понизив вас і {user0} в правах з модераторів",
    "{actor} demoted you and {user0} from moderators" : "{actor} понизили вас і {user0} з модераторів",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Адміністратор понизив вас у посаді, {user0} та ще %n учасників з модераторів","Адміністратор понизив вас, {user0} та ще %n учасників з модераторів","Адміністратор понизив вас, {user0} та ще %n учасників з модераторів","Адміністратор понизив вас, {user0} та ще %n учасників з модераторів"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} понизили вас, {user0} та ще %n учасників від модераторів.","{actor} понизили вас у посаді, {user0} та ще %n учасників від модераторів","{actor} понизили вас у посаді, {user0} та ще %n учасників від модераторів","{actor} понизили вас у посаді, {user0} та ще %n учасників від модераторів"],
    "An administrator demoted {user0} and {user1} from moderators" : "Адміністратор понизив {user0} та {user1} у званні модераторів",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} понизили {user0} та {user1} з модераторів",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Адміністратор понизив {user0}, {user1} та ще %n учасників з модераторів","Адміністратор понизив {user0}, {user1} та ще %n учасників з модераторів","Адміністратор понизив {user0}, {user1} та ще %n учасників з модераторів","Адміністратор понизив {user0}, {user1} та ще %n учасників з модераторів"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} понижено {user0}, {user1} та ще %n учасників від модераторів","{actor} понизили {user0}, {user1} та ще %n учасників з модераторів","{actor} понизили {user0}, {user1} та ще %n учасників з модераторів","{actor} понизили {user0}, {user1} та ще %n учасників з модераторів"],
    "You:" : "Ти:",
    "You: {lastMessage}" : "Ти: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(відредаговано вами)",
    "(edited by a deleted user)" : "(відредаговано видаленим користувачем)",
    "(edited by {moderator})" : "(за редакцією {moderator})",
    "The recording failed. Please contact your administrator." : "Запис не відбувся. Зверніться до адміністратора.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ви намагаєтеся приєднатися до розмови, маючи активну сесію в іншому вікні або на іншому пристрої. Наразі це не підтримується Nextcloud Talk. Що ви хочете зробити?",
    "Leave this page" : "Залиште цю сторінку",
    "Join here" : "Приєднуйтесь тут",
    "Deck card has been posted to {conversation}" : "Картку колоди опубліковано на {conversation}",
    "An error occurred while posting deck card to conversation" : "Виникла помилка під час публікації карти колоди в розмову",
    "Post to a conversation" : "Написати до розмови",
    "Post to conversation" : "Допис до розмови",
    "Location has been posted to {conversation}" : "Розташування було розміщено на {conversation}",
    "An error occurred while posting location to conversation" : "Виникла помилка під час додавання місцезнаходження до розмови",
    "Share to a conversation" : "Долучитися до розмови",
    "Share to conversation" : "Долучитися до розмови",
    "In conversation" : "У розмові",
    "Search in conversation: {conversation}" : "Шукайте в розмові: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Наразі ваші запити блокуються через захист від грубої сили",
    "Error while clearing conversation history" : "Помилка під час очищення історії розмов",
    "Error occurred while allowing guests" : "Виникла помилка під час входу гостей",
    "Error occurred while disallowing guests" : "Виникла помилка під час заборони гостей",
    "Error occurred when restricting the conversation to moderator" : "Виникла помилка при обмеженні розмови тільки модератором",
    "Error occurred when opening the conversation to everyone" : "Виникла помилка при відкритті розмови для всіх",
    "Conversation password has been saved" : "Пароль для розмови збережено",
    "Conversation password has been removed" : "Видалено пароль для розмови",
    "Error occurred while saving conversation password" : "Виникла помилка під час збереження пароля розмови",
    "Call recording is starting." : "Розпочато запис розмови.",
    "Call recording stopped while starting." : "Запис розмови зупинився під час запуску.",
    "Call recording stopped. You will be notified once the recording is available." : "Запис розмови зупинено. Ви отримаєте сповіщення, коли запис буде доступний.",
    "Conversation picture set" : "Зображення обговорення встановлено",
    "Conversation picture deleted" : "Зображення розмови вилучено",
    "Could not delete the conversation picture" : "Не вдалося вилучити зображення розмови",
    "Could not remove the automatic expiration" : "Не вдалося видалити автоматичне закінчення терміну дії",
    "Could not post message: {errorMessage}" : "Не вдалося опублікувати повідомлення: {errorMessage}",
    "Participant is banned successfully" : "Учасника успішно забанено",
    "Error while banning the participant" : "Помилка під час бану учасника",
    "An error occurred while fetching the participants" : "Виникла помилка під час отримання учасників",
    "Could not send invitation to {actorId}" : "Не вдалося надіслати запрошення до {actorId}",
    "Invitations sent" : "Запрошення надіслані",
    "Error occurred when sending invitations" : "Виникла помилка під час надсилання запрошень",
    "Failed to join the conversation." : "Не зміг долучитися до розмови.",
    "An error occurred while creating breakout rooms" : "Виникла помилка при створенні секційних кімнат",
    "An error occurred while re-ordering the attendees" : "Виникла помилка при повторному замовленні учасників",
    "An error occurred while deleting breakout rooms" : "Виникла помилка при видаленні секційних кімнат",
    "An error occurred while starting breakout rooms" : "Виникла помилка під час запуску секційних кімнат",
    "An error occurred while stopping breakout rooms" : "Виникла помилка під час зупинки секційних кімнат",
    "An error occurred while sending a message to the breakout rooms" : "Виникла помилка під час надсилання повідомлення до секційних кімнат",
    "An error occurred while requesting assistance" : "Виникла помилка під час запиту на допомогу",
    "An error occurred while resetting the request for assistance" : "Виникла помилка під час скидання запиту на допомогу",
    "An error occurred while joining breakout room" : "Виникла помилка під час приєднання до секційної кімнати",
    "Failed to rename the thread" : "Не вдалося перейменувати потік",
    "Error fetching upcoming events" : "Помилка при отриманні майбутніх подій",
    "Error fetching upcoming reminders" : "Помилка при отриманні майбутніх нагадувань",
    "An error occurred while accepting an invitation" : "Виникла помилка під час прийняття запрошення",
    "An error occurred while rejecting an invitation" : "Виникла помилка під час відхилення запрошення",
    "{guest} (guest)" : "{guest} (гість)",
    "Poll draft has been saved" : "Чернетка опитування збережена",
    "An error occurred while saving the draft" : "Виникла помилка під час збереження чернетки",
    "An error occurred while submitting your vote" : "Виникла помилка під час відправлення вашого голосу",
    "An error occurred while ending the poll" : "Виникла помилка при завершенні опитування",
    "An error occurred while deleting the poll draft" : "Виникла помилка при видаленні чернетки опитування",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Опитування \"{name}\" було створено {user}. Натисніть, щоб проголосувати",
    "Failed to add reaction" : "Не вдалося додати відповідь",
    "Failed to remove reaction" : "Не вдалося прибрати реакцію",
    "Error while uploading file \"{fileName}\"" : "Помилка під час завантаження файлу \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Недостатньо місця для завантаження файлу \"{fileName}\"",
    "You are not allowed to share files" : "Ви не маєте права ділитися файлами",
    "Error while sharing file" : "Помилка під час надання спільного доступу до файлу",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Браузер, який ви використовуєте, не повністю підтримується Nextcloud Talk. Будь ласка, використовуйте останню версію Mozilla Firefox, Microsoft Edge, Google Chrome, Opera або Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n година","%n години ","%n годин","%n годин"],
    "_%n day_::_%n days_" : ["%n день","%n днів","%n днів","%n днів"],
    "_%n week_::_%n weeks_" : ["%n день","%n тижнів","%n тижнів","%n тижнів"],
    "_In %n hour_::_In %n hours_" : ["Через %n годину","Через %n годин","Через %n годин","Через %n годин"],
    "_%n minute _::_%n minutes_" : ["%n хвилина","%n хвилин","%n хвилин","%n хвилин"],
    "In {hours} and {minutes}" : "Через {hours} годин і {minutes} хвилин",
    "_In %n minute_::_In %n minutes_" : ["Через %n хвилину","Через %n хвилин ","Через %n хвилин","Через %n хвилин"],
    "Later today – {timeLocale}" : "Пізніше сьогодні - {timeLocale}",
    "Tomorrow – {timeLocale}" : "Завтра - {timeLocale}",
    "This weekend – {timeLocale}" : "На цих вихідних - {timeLocale}",
    "Next week – {timeLocale}" : "Наступного тижня - {timeLocale}",
    "Message link copied to clipboard" : "Посилання на повідомлення скопійовано в буфер обміну",
    "Conversation link copied to clipboard" : "Посилання на розмову скопійовано до буфера обміну",
    "The link could not be copied" : "Посилання не вдалося скопіювати",
    "Error while parsing a PROPFIND error" : "Помилка під час обробки помилки PROPFIND",
    "Sending signaling message has failed" : "Не вдалося передати повідомлення сигналізації.",
    "Lost connection to signaling server. Trying to reconnect." : "Втрачено зв'язок із сервером сигналізації. Триває спроба відновити зв'язок.",
    "Lost connection to signaling server." : "Втрачено зв'язок із сервером сигналізації.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Встановлений сиґнальний сервер потрібно оновити, щоби його версія була сумісною з версією Talk. Будь ласка, сконтактуйте з адміністратором.",
    "Please restart the app." : "Будь ласка, перезапустіть програму.",
    "Please reload the page." : "Будь ласка, перезавантажте сторінку.",
    "Please try to restart the app." : "Спробуйте перезапустити програму.",
    "Please try to reload the page." : "Будь ласка, спробуйте перезавантажити сторінку.",
    "Do not disturb" : "Не турбувати",
    "Away" : "Відсутній(-я)",
    "Microphone {number}" : "Мікрофон {number}",
    "Camera {number}" : "Камера {number}",
    "Speaker {number}" : "Доповідач {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Здається, ви говорите з вимкненим мікрофоном, будь ласка, увімкніть його, щоб інші могли вас почути",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Не вдалося встановити з'єднання принаймні з одним учасником. Для вашого сценарію може знадобитися сервер TURN. Попросіть адміністратора налаштувати його відповідно до {linkstart} цієї документації{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Це займає більше часу, ніж очікувалося. Чи вже надано (або відхилено) дозволи для медіа? Якщо так, перезапустіть браузер, оскільки аудіо та відео не працюють.",
    "Access to microphone & camera is only possible with HTTPS" : "Доступ до мікрофона та камери можливий лише через безпечний протокол https.",
    "Please move your setup to HTTPS" : "Будь ласка, налаштуйте безпечний доступ до сервера через https.",
    "Access to microphone & camera was denied" : "У доступі до мікрофону та камери було відмовлено",
    "WebRTC is not supported in your browser" : "WebRTC не підтримується у вашому браузері",
    "Please use a different browser like Firefox or Chrome" : "Будь ласка, використовуйте інший браузер, наприклад, Firefox або Chrome",
    "Error while accessing microphone & camera" : "Помилка під час доступу до мікрофона та камери",
    "%s Talk on your mobile devices" : "%s Talk на мобільних пристроях",
    "Join conversations at any time, anywhere, on any device." : "Приєднуйтесь до розмов у будь-який час, у будь-якому місці, на будь-якому пристрої.",
    "Android app" : "Застосунок для Android",
    "iOS app" : "Застосунок для iOS",
    "__language_name__" : "Українська",
    "Webhook Demo" : "Демонстраційна версія Webhook",
    "Call summary (%s)" : "Підсумки дзвінків (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Після дзвінка бот підбиває підсумки розмови та публікує оглядове повідомлення з переліком усіх учасників і завданнями",
    "Tasks" : "Завдання",
    "Notes" : "Нотатки",
    "Reports" : "Звіти",
    "Decisions" : "Рішення",
    "Agenda" : "Порядок денний",
    "Call summary" : "Підсумки дзвінка",
    "Call summary - {title}" : "Підсумки дзвінків - {title}",
    "Talk to %s" : "Спілкуватися з %s",
    "Talk conversation for event" : "Розмова Talk для події",
    "Client Push is installed, this improves the performance of desktop clients." : "Встановлено Client Push, це покращує продуктивність десктопних клієнтів.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} не встановлено, це може призвести до проблем з продуктивністю під час використання десктопних клієнтів.",
    "Next meeting" : "Наступна зустріч",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Заплануйте зустріч у своєму календарі. Щоб розмова з'явилася тут, потрібно вказати місце, де вона буде проходити",
    "Join conversations from remote Nextcloud servers" : "Приєднуйтесь до розмов з віддалених серверів Nextcloud",
    "Your default media state has been saved" : "Збережено стан медіа за замовчуванням",
    "Set reminder for later today" : "Встановити нагадування на сьогодні пізніше",
    "Set reminder for tomorrow" : "Встановити нагадування на завтра",
    "Set reminder for this weekend" : "Встановити нагадування на ці вихідні",
    "Set reminder for next week" : "Встановити нагадування на наступний тиждень",
    "Generate summary" : "Згенерувати підсумок",
    "Open poll • You voted already" : "Відкрите опитування - Ви вже проголосували",
    "Open poll • Click to vote" : "Відкрите опитування - Натисніть, щоб проголосувати",
    "Poll • Ended" : "Опитування - Завершено",
    "Talk recording from {time} ({conversation})" : "Запис розмови з {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Результати опитування - %n голосів","Результати опитування - %n голосів","Результати опитування - %n голосів","Результати опитування - %n голосів"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Відкрите голосування - %n голосів","Відкрите голосування - %n голосів","Відкрите голосування - %n голосів","Відкрите голосування - %n голосів"],
    "Submit vote" : "Подати голос",
    "Your privacy setting has been saved" : "Ваші налаштування конфіденційності збережено",
    "Your personal setting has been saved" : "Ваші персональні налаштування збережено",
    "Failed to save sounds setting" : "Не вдалося зберегти налаштування звуків",
    "Sounds setting saved" : "Налаштування звуків збережено",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk оновлено, ви не можете розпочати або приєднатися до виклику.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Ви приєдналися до розмови в іншому вікні або на іншому пристрої. Наразі Nextcloud Talk не підтримує таку функцію, тому ця сесія була закрита.",
    "Nextcloud Talk was updated." : "Оновлений Nextcloud Talk.",
    "Nextcloud is in maintenance mode." : "Nextcloud знаходиться в режимі технічного обслуговування.",
    "Nextcloud Talk Federation was updated." : "Оновлена Nextcloud Talk Federation."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
